@@ -52,6 +52,7 @@ struct KColumn;
  */
 enum
 {
+    ccrpt_Raw,
     ccrpt_Done,
     ccrpt_MD5,
     ccrpt_Blob,
@@ -89,7 +90,7 @@ struct CCReportInfoBlock
         {
             uint64_t start;
             uint64_t count;
-
+            bool missingChecksum;
         } blob;
 
         struct ccrb_index_s
@@ -99,7 +100,6 @@ struct CCReportInfoBlock
             uint64_t num_keys;
             uint64_t num_rows;
             uint64_t num_holes;
-
         } index;
         
         struct ccrb_visit_s {
