@@ -31,6 +31,7 @@
 
 #define KONST const
 #include "dbmgr.h"
+#include "rdbmgr.h"
 #include "kdb-cmn.h"
 #include "kdbfmt.h"
 #undef KONST
@@ -150,29 +151,6 @@ rc_t KDBManagerMake ( KDBManager **mgrp, const KDirectory *wd, const char *op,
     return rc;
 }
 
-
-LIB_EXPORT rc_t CC KDBManagerGetVFSManager ( const KDBManager *self,
-    const struct VFSManager **vmanager )
-{
-    if (self == NULL) {
-        return RC ( rcDB, rcMgr, rcAccessing, rcSelf, rcNull );
-    }
-    else if (vmanager == NULL) {
-        return RC ( rcDB, rcMgr, rcAccessing, rcParam, rcNull );
-    }
-    else {
-        rc_t rc = VFSManagerAddRef(self -> vfsmgr);
-        if (rc == 0) {
-            * vmanager = self -> vfsmgr;
-        }
-        else {
-            * vmanager = NULL;
-        }
-        return rc;
-    }
-}
-
-
 /* Version
  *  returns the library version
  */
@@ -427,3 +405,33 @@ rc_t KDBHdrValidate ( const KDBHdr *hdr, size_t size,
 
     return 0;
 }
+
+rc_t CC KDBCmnManagerGetVFSManager ( const KDBManager *self, const struct VFSManager **vmanager )
+{
+    if (self == NULL) {
+        return RC ( rcDB, rcMgr, rcAccessing, rcSelf, rcNull );
+    }
+    else if (vmanager == NULL) {
+        return RC ( rcDB, rcMgr, rcAccessing, rcParam, rcNull );
+    }
+    else {
+        rc_t rc = VFSManagerAddRef(self -> vfsmgr);
+        if (rc == 0) {
+            * vmanager = self -> vfsmgr;
+        }
+        else {
+            * vmanager = NULL;
+        }
+        return rc;
+    }
+}
+
+LIB_EXPORT rc_t CC KDBManagerPathContents(const KDBManager *self, KDBContents const **result, int levelOfDetail, const char *path, ...)
+{
+    rc_t rc = 0;
+    va_list ap;
+    va_start(ap, path);
+    rc = KDBRManagerVPathContents(self, result, levelOfDetail, path, ap);
+    va_end(ap);
+    return rc;
+}
