@@ -32,7 +32,8 @@
 #include <strtol.h>
 #include <limits.h>
 
-rc_t KMDataNodeBaseWhack ( KMDataNode *self )
+rc_t
+KMDataNodeBaseWhack ( KMDataNode *self )
 {
     KRefcountWhack ( & self -> refcount, "KMDataNode" );
     free ( self );
@@ -44,7 +45,8 @@ rc_t KMDataNodeBaseWhack ( KMDataNode *self )
  *  all objects are reference counted
  *  NULL references are ignored
  */
-rc_t CC KMDataNodeBaseAddRef ( const KMDataNode *self )
+rc_t CC
+KMDataNodeBaseAddRef ( const KMDataNode *self )
 {
     if ( self != NULL )
     {
@@ -57,6 +59,25 @@ rc_t CC KMDataNodeBaseAddRef ( const KMDataNode *self )
     return 0;
 }
 
+rc_t CC
+KMDataNodeBaseRelease ( const KMDataNode *self )
+{
+    if ( self != NULL )
+    {
+        switch ( KRefcountDrop ( & self -> refcount, "KMDataNode" ) )
+        {
+        case krefOkay:
+            break;
+        case krefWhack:
+            KMDataNodeWhack( (KMDataNode*)self );
+            break;
+        case krefNegative:
+            return RC ( rcDB, rcMetadata, rcReleasing, rcRange, rcExcessive );
+        }
+    }
+    return 0;
+}
+
 /* Attach
  * Sever
  */
@@ -93,7 +114,7 @@ rc_t KMDataNodeSever ( const KMDataNode *self )
     if ( self != NULL && self -> vt != NULL )   \
         return self -> vt -> call;              \
     else                                        \
-        return RC ( rcVDB, rcMgr, rcAccessing, rcSelf, rcNull );
+        return RC ( rcDB, rcMgr, rcAccessing, rcSelf, rcNull );
 #define DISPATCH_BOOL(call)  \
     if ( self != NULL && self -> vt != NULL )   \
         return self -> vt -> call;              \
