@@ -26,28 +26,9 @@
 
 #pragma once
 
-#include "columnblob-base.h"
-
-#include "rcoldata.h"
-#include "colfmt.h"
+#include <kdb/column.h>
 
 struct KRColumn;
 
-typedef struct KRColumnBlob KRColumnBlob;
-struct KRColumnBlob
-{
-    KColumnBlob dad;
-
-    /* owning column */
-    const struct KRColumn *col;
-
-    /* captured from idx1 for CRC32 validation */
-    bool bswap;
-
-    /* holds existing blob loc */
-    KColBlobLoc loc;
-    KRColumnPageMap pmorig;
-};
-
-rc_t KRColumnBlobMake ( KRColumnBlob **blobp, bool bswap );
-rc_t KRColumnBlobOpenRead ( KRColumnBlob *self, const struct KRColumn *col, int64_t id );
+rc_t KRColumnBlobMake ( const KColumnBlob **blobp, bool bswap );
+rc_t KRColumnBlobOpenRead ( const KColumnBlob *self, const struct KRColumn *col, int64_t id );
