@@ -28,6 +28,7 @@
 #include <kfs/impl.h>
 #include <klib/rc.h>
 #include <kproc/timeout.h>
+#include <klib/status.h>
 #include <os-native.h>
 #include <sysalloc.h>
 
@@ -314,6 +315,8 @@ LIB_EXPORT rc_t CC KFileReadAll_v1 ( const KFile_v1 *self, uint64_t pos,
     if ( bsize == 0 )
         return RC ( rcFS, rcFile, rcReading, rcBuffer, rcInsufficient );
 
+    STATUS ( STAT_GEEK, "%s ( %p, %lu, %p, %zu )\n", __func__, self, pos, buffer, bsize );
+
     switch ( self -> vt -> v1 . maj )
     {
     case 1:
@@ -321,6 +324,8 @@ LIB_EXPORT rc_t CC KFileReadAll_v1 ( const KFile_v1 *self, uint64_t pos,
         rc = ( * self -> vt -> v1 . read ) ( self, pos, buffer, bsize, & count );
         total = count;
 
+        STATUS ( STAT_GEEK, "%s initial read rc = %R, count = %zu\n", __func__, rc, count );
+
         if ( rc == 0 && count != 0 && count < bsize )
         {
             if ( self -> vt -> v1 . min >= 2 )
@@ -328,26 +333,44 @@ LIB_EXPORT rc_t CC KFileReadAll_v1 ( const KFile_v1 *self, uint64_t pos,
                 timeout_t no_block;
                 TimeoutInit ( & no_block, 0 );
 
+                STATUS ( STAT_GEEK, "%s using non-blocking read-all\n", __func__ );
+
                 for ( b = buffer; total < bsize; total += count )
                 {
                     count = 0;
                     rc = ( * self -> vt -> v1 . timed_read ) ( self, pos + total, b + total, bsize - total, & count, & no_block );
+                    STATUS ( STAT_GEEK, "%s ( %p, %lu, %p, %zu, [ %zu ] )\n", __func__, self, pos + total, b + total, bsize - total, count );
                     if ( rc != 0 )
+                    {
+                        STATUS ( STAT_GEEK, "%s - breaking loop with rc = %R\n", __func__, rc );
                         break;
+                    }
                     if ( count == 0 )
+                    {
+                        STATUS ( STAT_GEEK, "%s - breaking loop with count == 0\n", __func__ );
                         break;
+                    }
                 }
             }
             else
             {
+                STATUS ( STAT_GEEK, "%s using blocking read-all\n", __func__ );
+                
                 for ( b = buffer; total < bsize; total += count )
                 {
                     count = 0;
                     rc = ( * self -> vt -> v1 . read ) ( self, pos + total, b + total, bsize - total, & count );
+                    STATUS ( STAT_GEEK, "%s ( %p, %lu, %p, %zu, [ %zu ] )\n", __func__, self, pos + total, b + total, bsize - total, count );
                     if ( rc != 0 )
+                    {
+                        STATUS ( STAT_GEEK, "%s - breaking loop with rc = %R\n", __func__, rc );
                         break;
+                    }
                     if ( count == 0 )
+                    {
+                        STATUS ( STAT_GEEK, "%s - breaking loop with count == 0\n", __func__ );
                         break;
+                    }
                 }
             }
         }
@@ -415,8 +438,10 @@ LIB_EXPORT rc_t CC KFileTimedReadAll_v1 ( const KFile_v1 *self, uint64_t pos,
             break;
         }
 
+        STATUS ( STAT_GEEK, "%s - target %p is not capable of receiving timed read message\n", __func__, self );
         if ( tm == NULL )
         {
+            STATUS ( STAT_GEEK, "%s - no timeout specified - call will succeed\n", __func__ );
             for ( rc = 0, b = buffer, total = 0; total < bsize; total += count )
             {
                 count = 0;
@@ -429,6 +454,8 @@ LIB_EXPORT rc_t CC KFileTimedReadAll_v1 ( const KFile_v1 *self, uint64_t pos,
             break;
         }
 
+        STATUS ( STAT_GEEK, "%s - timeout specified - call will fail\n", __func__ );
+
         /* no break */
     default:
         return RC ( rcFS, rcFile, rcReading, rcInterface, rcBadVersion );
@@ -574,6 +601,75 @@ LIB_EXPORT rc_t CC KFileTimedReadExactly_v1 ( const KFile_v1 *self,
     return rc;
 }
 
+
+/* ReadChunked
+ * TimedReadChunked
+ *  behaves like Read or TimedRead,
+ *  except that bytes read are delivered via callback message
+ *  there may be multiple such messages, allowing a long
+ *  synchronous read with multiple intermediate delivery.
+ */
+LIB_EXPORT rc_t CC KFileReadChunked_v1 ( const KFile_v1 *self, uint64_t pos,
+    struct KChunkReader * chunks, size_t bytes, size_t * num_read )
+{
+    if ( num_read == NULL )
+        return RC ( rcFS, rcFile, rcReading, rcParam, rcNull );
+
+    * num_read = 0;
+
+    if ( self == NULL )
+        return RC ( rcFS, rcFile, rcReading, rcSelf, rcNull );
+
+    if ( ! self -> read_enabled )
+        return RC ( rcFS, rcFile, rcReading, rcFile, rcNoPerm );
+
+    if ( chunks == NULL )
+        return RC ( rcFS, rcFile, rcReading, rcBuffer, rcNull );
+    if ( bytes == 0 )
+        return RC ( rcFS, rcFile, rcReading, rcBuffer, rcInsufficient );
+
+    switch ( self -> vt -> v1 . maj )
+    {
+    case 1:
+        if ( self -> vt -> v1 . min >= 3 )
+            return ( * self -> vt -> v1 . read_chunked ) ( self, pos, chunks, bytes, num_read );
+        break;
+    }
+
+    return RC ( rcFS, rcFile, rcReading, rcInterface, rcBadVersion );
+}
+
+LIB_EXPORT rc_t CC KFileTimedReadChunked_v1 ( const KFile_v1 *self, uint64_t pos,
+    struct KChunkReader * chunks, size_t bytes, size_t * num_read, struct timeout_t *tm )
+{
+    if ( num_read == NULL )
+        return RC ( rcFS, rcFile, rcReading, rcParam, rcNull );
+
+    * num_read = 0;
+
+    if ( self == NULL )
+        return RC ( rcFS, rcFile, rcReading, rcSelf, rcNull );
+
+    if ( ! self -> read_enabled )
+        return RC ( rcFS, rcFile, rcReading, rcFile, rcNoPerm );
+
+    if ( chunks == NULL )
+        return RC ( rcFS, rcFile, rcReading, rcBuffer, rcNull );
+    if ( bytes == 0 )
+        return RC ( rcFS, rcFile, rcReading, rcBuffer, rcInsufficient );
+
+    switch ( self -> vt -> v1 . maj )
+    {
+    case 1:
+        if ( self -> vt -> v1 . min >= 3 )
+            return ( * self -> vt -> v1 . timed_read_chunked ) ( self, pos, chunks, bytes, num_read, tm );
+        break;
+    }
+
+    return RC ( rcFS, rcFile, rcReading, rcInterface, rcBadVersion );
+}
+
+
 /* Write
  *  write file at known position
  *
@@ -799,6 +895,129 @@ LIB_EXPORT rc_t CC KFileTimedWriteAll_v1 ( KFile_v1 *self, uint64_t pos,
     return rc;
 }
 
+/* WriteExactly
+ *  write from file until "size" bytes have been transferred
+ *
+ *  "pos" [ IN ] - starting position within file
+ *
+ *  "buffer" [ IN ] and "size" [ IN ] - data to be written
+ */
+LIB_EXPORT rc_t CC KFileWriteExactly_v1 ( KFile_v1 *self, uint64_t pos,
+    const void *buffer, size_t size )
+{
+    rc_t rc;
+    const uint8_t *b;
+    size_t total, count;
+
+    if ( self == NULL )
+        return RC ( rcFS, rcFile, rcWriting, rcSelf, rcNull );
+
+    if ( ! self -> write_enabled )
+        return RC ( rcFS, rcFile, rcWriting, rcFile, rcNoPerm );
+
+    if ( size == 0 )
+        return 0;
+    if ( buffer == NULL )
+        return RC ( rcFS, rcFile, rcWriting, rcBuffer, rcNull );
+
+    switch ( self -> vt -> v1 . maj )
+    {
+    case 1:
+        for ( b = buffer, total = 0; total < size; total += count )
+        {
+            count = 0;
+            rc = ( * self -> vt -> v1 . write ) ( self, pos + total, b + total, size - total, & count );
+            if ( rc != 0 )
+            {
+                if ( GetRCObject ( rc ) != ( enum RCObject ) rcTimeout || GetRCState ( rc ) != rcExhausted )
+                    break;
+            }
+            else if ( count == 0 )
+            {
+                rc = RC ( rcFS, rcFile, rcWriting, rcTransfer, rcIncomplete );
+                break;
+            }
+        }
+        break;
+    default:
+        rc = RC ( rcFS, rcFile, rcWriting, rcInterface, rcBadVersion );
+    }
+
+    return rc;
+}
+
+LIB_EXPORT rc_t CC KFileTimedWriteExactly_v1 ( KFile_v1 *self, uint64_t pos,
+    const void *buffer, size_t size, struct timeout_t *tm )
+{
+    rc_t rc;
+    const uint8_t *b;
+    size_t total, count;
+
+    if ( self == NULL )
+        return RC ( rcFS, rcFile, rcWriting, rcSelf, rcNull );
+
+    if ( ! self -> write_enabled )
+        return RC ( rcFS, rcFile, rcWriting, rcFile, rcNoPerm );
+
+    if ( size == 0 )
+        return 0;
+    if ( buffer == NULL )
+        return RC ( rcFS, rcFile, rcWriting, rcBuffer, rcNull );
+
+    switch ( self -> vt -> v1 . maj )
+    {
+    case 1:
+        if ( self -> vt -> v1 . min >= 2 )
+        {
+            for ( b = buffer, total = 0; total < size; total += count )
+            {
+                count = 0;
+                rc = ( * self -> vt -> v1 . timed_write ) ( self, pos + total, b + total, size - total, & count, tm );
+                if ( rc != 0 )
+                {
+                    if ( tm != NULL )
+                        break;
+                    if ( GetRCObject ( rc ) != ( enum RCObject ) rcTimeout || GetRCState ( rc ) != rcExhausted )
+                        break;
+                }
+                else if ( count == 0 )
+                {
+                    rc = RC ( rcFS, rcFile, rcWriting, rcTransfer, rcIncomplete );
+                    break;
+                }
+            }
+            break;
+        }
+
+        if ( tm == NULL )
+        {
+            for ( b = buffer, total = 0; total < size; total += count )
+            {
+                count = 0;
+                rc = ( * self -> vt -> v1 . write ) ( self, pos + total, b + total, size - total, & count );
+                if ( rc != 0 )
+                {
+                    if ( GetRCObject ( rc ) != ( enum RCObject ) rcTimeout || GetRCState ( rc ) != rcExhausted )
+                        break;
+                }
+                else if ( count == 0 )
+                {
+                    rc = RC ( rcFS, rcFile, rcWriting, rcTransfer, rcIncomplete );
+                    break;
+                }
+            }
+            break;
+        }
+
+        /* no break */
+
+    default:
+        rc = RC ( rcFS, rcFile, rcWriting, rcInterface, rcBadVersion );
+    }
+
+    return rc;
+}
+
 /* Init
  *  initialize a newly allocated file object
  */
@@ -819,6 +1038,12 @@ LIB_EXPORT rc_t CC KFileInit ( KFile_v1 *self, const KFile_vt *vt,
         switch ( vt -> v1 . min )
         {
             /* ADD NEW MINOR VERSION CASES HERE */
+        case 3:
+#if _DEBUGGING
+            if ( vt -> v1 . timed_read_chunked == NULL ||
+                 vt -> v1 . read_chunked == NULL )
+                return RC ( rcFS, rcFile, rcConstructing, rcInterface, rcNull );
+#endif
         case 2:
 #if _DEBUGGING
             if ( vt -> v1 . timed_write == NULL ||
