@@ -37,6 +37,15 @@
 #include <string.h>
 #include <assert.h>
 
+#include "int_checks-priv.h"
+
+#ifdef WINDOWS
+#pragma warning(disable:4127)
+/*
+sizeof key > sizeof ( Word_t ) is a valid condition for
+C cross-platform code
+*/
+#endif
 
 /*--------------------------------------------------------------------------
  * KVector
@@ -235,7 +244,7 @@ LIB_EXPORT rc_t CC KVectorGet ( const KVector *self, uint64_t key,
         {
             if ( self -> nancy_bool )
             {
-                bool data;
+                bool data = false;
                 rc = Nancy1Test ( self -> nancy, key, & data );
                 if ( rc == 0 )
                 {
@@ -249,7 +258,7 @@ LIB_EXPORT rc_t CC KVectorGet ( const KVector *self, uint64_t key,
             }
             else
             {
-                Word_t data;
+                Word_t data = 0;
                 rc = NancyLGet ( self -> nancy, key, & data );
                 if ( rc == 0 )
                 {
@@ -482,7 +491,7 @@ LIB_EXPORT rc_t CC KVectorGetFirst ( const KVector *self, uint64_t *first,
             rc = RC ( rcCont, rcVector, rcAccessing, rcType, rcUnsupported );
         else
         {
-            Word_t data;
+            Word_t data = 0;
             rc = NancyLGetFirst ( self -> nancy, first, & data );
             if ( rc == 0 )
             {
@@ -696,7 +705,7 @@ KLIB_EXTERN rc_t CC KVectorGetPrev ( const KVector *self, uint64_t *prev,
         {
             if ( self -> nancy_bool )
             {
-                bool data;
+                bool data = false;
                 rc = Nancy1TestPrev ( self -> nancy, prev, key, & data );
                 if ( rc == 0 )
                 {
@@ -710,7 +719,7 @@ KLIB_EXTERN rc_t CC KVectorGetPrev ( const KVector *self, uint64_t *prev,
             }
             else
             {
-                Word_t data;
+                Word_t data = 0;
                 rc = NancyLGetPrev ( self -> nancy, prev, key, & data );
                 if ( rc == 0 )
                 {
@@ -967,7 +976,7 @@ KLIB_EXTERN rc_t CC KVectorGetNext ( const KVector *self, uint64_t *next,
         {
             if ( self -> nancy_bool )
             {
-                bool data;
+                bool data = false;
                 rc = Nancy1TestNext ( self -> nancy, next, key, & data );
                 if ( rc == 0 )
                 {
@@ -981,7 +990,7 @@ KLIB_EXTERN rc_t CC KVectorGetNext ( const KVector *self, uint64_t *next,
             }
             else
             {
-                Word_t data;
+                Word_t data = 0;
                 rc = NancyLGetNext ( self -> nancy, next, key, & data );
                 if ( rc == 0 )
                 {
@@ -1229,7 +1238,7 @@ LIB_EXPORT rc_t CC KVectorSet ( KVector *self, uint64_t key,
         rc = RC ( rcCont, rcVector, rcWriting, rcParam, rcEmpty );
     else
     {
-        Word_t value;
+        Word_t value = 0;
 
         /* detect first set */
         if ( self -> nancy == NULL )
@@ -1476,7 +1485,7 @@ LIB_EXPORT rc_t CC KVectorVisit ( const KVector *self, bool reverse,
             JError_t err;
             Word_t first, last, idx;
 
-	    /** Judy1First searches for first value higher then first**/ 
+	    /** Judy1First searches for first value higher then first**/
             first = 0;
 	    /** Judy1Last searches for first value lower then last **/
             last = (Word_t)-1;
@@ -1527,7 +1536,7 @@ LIB_EXPORT rc_t CC KVectorVisit ( const KVector *self, bool reverse,
             else
             {
                 Word_t value;
-                PPvoid_t lastp, datap = JudyLFirst ( self -> nancy, & first, & err );
+                PPvoid_t lastp = NULL, datap = JudyLFirst ( self -> nancy, & first, & err );
                 if ( datap != PPJERR )
                     lastp = JudyLLast ( self -> nancy, & last, & err );
                 if ( datap == PPJERR || lastp == PPJERR )
@@ -1668,7 +1677,9 @@ LIB_EXPORT rc_t CC KVectorVisitBool ( const KVector *self, bool reverse,
     rc_t ( CC * f ) ( uint64_t key, bool value, void *user_data ),
     void *user_data )
 {
-    UserDataStoredBitstoBool user_data_adapter = { f, user_data };
+    UserDataStoredBitstoBool user_data_adapter;
+    user_data_adapter.f = f;
+    user_data_adapter.user_data = user_data;
     return KVectorBoolVisitStoredBits ( self, reverse, VisitStoredBitstoBoolAdapter, &user_data_adapter );
 }
 
@@ -1728,7 +1739,8 @@ LIB_EXPORT rc_t CC KVectorVisitU64 ( const KVector *self, bool reverse,
 rc_t CC KVectorVisitU32Func ( uint64_t key, const void *ptr, size_t bytes, void *user_data )
 {
     KVectorVisitTypedData *pb = user_data;
-    return ( * pb -> f . u32 ) ( key, * ( const Word_t* ) ptr, pb -> user_data );
+    assert ( FITS_INTO_INT32 ( (*(const Word_t*)ptr) ) );
+    return ( * pb -> f . u32 ) ( key, (uint32_t)(* ( const Word_t* ) ptr), pb -> user_data );
 }
 
 LIB_EXPORT rc_t CC KVectorVisitU32 ( const KVector *self, bool reverse,
