@@ -55,6 +55,8 @@ typedef struct KClientHttpStream KClientHttpStream;
 
 #include <ctype.h>
 
+#include "../klib/int_checks-priv.h"
+
 #if _DEBUGGING && 0
 #include <stdio.h>
 #define TRACE( x, ... ) \
@@ -74,7 +76,7 @@ typedef struct KClientHttpStream KClientHttpStream;
 
 enum
 {
-    _STAT_USR = 2,       /* normal user verbosity  */
+    _STAT_USR = 3,       /* normal user verbosity  */
     _STAT_PWR,           /* power-user verbosity   */
     _STAT_QA,            /* qa-level description   */
     _STAT_PRG,           /* programmer description */
@@ -326,7 +328,8 @@ struct KEndPointArgsIterator * KNSManagerMakeKEndPointArgsIterator (
 {
     struct KEndPointArgsIterator * i = calloc ( 1, sizeof * i );
 
-    KEndPointArgsIteratorMake ( i, self, hostname, port, cnt );
+    assert(FITS_INTO_INT16(port));
+    KEndPointArgsIteratorMake ( i, self, hostname, (uint16_t)port, cnt );
 
     return i;
 }
@@ -478,7 +481,15 @@ rc_t KClientHttpOpen ( KClientHttp * self, const String * aHostname, uint32_t aP
     static bool INITED = false;
     static bool PRINT_STAT = false;
     if (!INITED) {
+#ifdef WINDOWS
+    {
+        size_t buf_size;
+        errno_t err = getenv_s ( & buf_size, NULL, 0, "NCBI_VDB_STS_SILENT" );
+        PRINT_STAT = ( err != 0 || buf_size == 0 );
+    }
+#else
         PRINT_STAT = getenv("NCBI_VDB_STS_SILENT") == NULL;
+#endif
         INITED = true;
     }
 
@@ -488,7 +499,8 @@ rc_t KClientHttpOpen ( KClientHttp * self, const String * aHostname, uint32_t aP
     mgr = self -> mgr;
     assert ( mgr );
 
-    KEndPointArgsIteratorMake ( & it, mgr, aHostname, aPort, NULL );
+    assert ( FITS_INTO_INT16 ( aPort ) );
+    KEndPointArgsIteratorMake ( & it, mgr, aHostname, (uint16_t)aPort, NULL );
     while ( KEndPointArgsIteratorNext ( & it, & hostname, & port,
         & proxy_default_port, & proxy_ep, NULL, NULL ) )
     {
@@ -518,8 +530,9 @@ rc_t KClientHttpOpen ( KClientHttp * self, const String * aHostname, uint32_t aP
             /* try to establish a connection */
             /*  "read_timeout", "write_timeout"
                     - when negative,  infinite timeout */
-            rc = KNSManagerMakeTimedConnection(mgr, &sock,
-                self->read_timeout, self->write_timeout, NULL, &self->ep);
+            rc = KNSManagerMakeTimedConnectionExt(mgr, &sock,
+                self->conn_timeout, self->read_timeout, self->write_timeout,
+                NULL, &self->ep);
 
             /* if we connected to a proxy, try to follow-through to server */
             if (proxy_ep && self->tls && rc == 0)
@@ -702,7 +715,7 @@ rc_t KClientHttpInit ( KClientHttp * http, const KDataBuffer *hostname_buffer, v
 
     if ( rc == 0 )
     {
-        const char * s;
+        const char * s = NULL;
         const char * ua = NULL;
         rc = KNSManagerGetUserAgent(&ua);
         if (rc == 0)
@@ -771,7 +784,7 @@ rc_t KClientHttpInit ( KClientHttp * http, const KDataBuffer *hostname_buffer, v
  */
 rc_t KNSManagerMakeClientHttpInt ( const KNSManager *self, KClientHttp **_http,
     const KDataBuffer *hostname_buffer,  KStream *opt_conn,
-    ver_t vers, int32_t readMillis, int32_t writeMillis,
+    ver_t vers, int32_t connMillis, int32_t readMillis, int32_t writeMillis,
     const String *host, uint32_t port, bool reliable, bool tls )
 {
     rc_t rc;
@@ -787,6 +800,7 @@ rc_t KNSManagerMakeClientHttpInt ( const KNSManager *self, KClientHttp **_http,
             char save, *text;
 
             http -> mgr = self;
+            http -> conn_timeout = connMillis;
             http -> read_timeout = readMillis;
             http -> write_timeout = writeMillis;
 
@@ -896,8 +910,9 @@ rc_t KNSManagerMakeTimedClientHttpInt ( const KNSManager *self,
                     port = dflt_port;
 
                 /* initialize http object - will create a new reference to hostname buffer */
-                rc = KNSManagerMakeClientHttpInt ( self, _http, & hostname_buffer,
-                    opt_conn, vers, readMillis, writeMillis, &_host, port, false, tls );
+                rc = KNSManagerMakeClientHttpInt ( self, _http,
+                    & hostname_buffer, opt_conn, vers, self->conn_timeout,
+                    readMillis, writeMillis, &_host, port, false, tls );
 
                 /* release our reference to buffer */
                 KDataBufferWhack ( & hostname_buffer );
@@ -1506,7 +1521,7 @@ rc_t KClientHttpGetStatusLine ( KClientHttp *self, timeout_t *tm, String *msg, u
                     else
                     {
                         /* which version was returned? */
-                        * version = string_cmp ( "1.0", 3, buffer, sep - buffer, -1 ) == 0 ? 0x01000000 : 0x01010000;
+                        * version = string_cmp ( "1.0", 3, buffer, sep - buffer, (uint32_t)-1 ) == 0 ? 0x01000000 : 0x01010000;
 
                         /* move up to status code */
                         buffer = sep + 1;
@@ -1915,7 +1930,7 @@ rc_t KClientHttpSendReceiveMsg ( KClientHttp *self, KClientHttpResult **rslt,
     const char *buffer, size_t len, const KDataBuffer *body, const char *url )
 {
     rc_t rc = 0;
-    size_t sent;
+    size_t sent = 0;
     timeout_t tm;
     timeout_t * ptm = NULL;
     uint32_t status;
@@ -2601,7 +2616,7 @@ LIB_EXPORT bool CC KClientHttpResultTestHeaderValue ( const KClientHttpResult *s
                     sep = end;
 
                 /* test for case-insensitive match of value */
-                if ( strcase_cmp ( start, sep - start, value, val_size, -1 ) == 0 )
+                if ( strcase_cmp ( start, sep - start, value, val_size, (uint32_t)-1 ) == 0 )
                 {
                     /* found it - delete p if malloc'd */
                     if ( p != buffer && p != NULL )
