@@ -73,6 +73,8 @@
 #include <kfs/chunk-reader.h>
 #endif
 
+#include "../klib/int_checks-priv.h"
+
 #if _DEBUGGING && 0
 #include <stdio.h>
 #define TRACE( x, ... ) \
@@ -396,7 +398,12 @@ rc_t KHttpFileTimedReadInt ( const KHttpFile * self,
                 /* NO BREAK */
 
             default:
-                rc = RC ( rcNS, rcFile, rcReading, rcData, rcUnexpected );
+                if ( * http_status == 403 )
+                    rc = RC ( rcNS, rcFile, rcReading, rcData, rcUnauthorized );
+                else if ( * http_status == 500 )
+                    rc = RC ( rcNS, rcFile, rcReading, rcError, rcExists );
+                else
+                    rc = RC ( rcNS, rcFile, rcReading, rcData, rcUnexpected );
                 TRACE ( "KClientHttpResultStatus ( rslt, & http_status, NULL, 0, NULL ); "
                         "unexpected status=%d\n", * http_status );
                 break;
@@ -740,14 +747,18 @@ rc_t KHttpFileTimedReadLocked ( const KHttpFile * self,
     uint64_t pos, void * buf, size_t bsize, size_t * num_read,
     struct timeout_t * tm, uint32_t * http_status )
 {
-    rc_t rc = KLockAcquire ( self -> lock );
+    rc_t rc = 0;
+    assert(self && num_read && http_status);
+    rc = KLockAcquire(self->lock);
     if ( rc == 0 )
     {
 #if SUPPORT_CHUNKED_READ
         /* moved the request boundary processing here.
            first, check trivial case of read beyond EOF. */
-        if ( pos >= self -> file_size )
+        if ( pos >= self -> file_size ) {
             * num_read = 0;
+            * http_status = 200;
+        }
         else
         {
             /* limit read request to amount available in file */
@@ -793,12 +804,12 @@ rc_t CC KHttpFileTimedRead ( const KHttpFile *self,
             rc = KHttpFileTimedReadLocked ( self, pos, buffer, bsize, num_read, tm, & http_status );
             if ( rc != 0 )
             {
-                rc_t rc2=KClientHttpReopen ( self -> http );
+                rc_t rc3=KClientHttpReopen ( self -> http );
                 DBGMSG ( DBG_KNS, DBG_FLAG ( DBG_KNS_HTTP ), ( "KHttpFileTimedRead: KHttpFileTimedReadLocked failed, reopening\n" ) );
-                if ( rc2 == 0 )
+                if ( rc3 == 0 )
                 {
-                    rc2 = KHttpFileTimedReadLocked ( self, pos, buffer, bsize, num_read, tm, & http_status );
-                    if ( rc2 == 0 )
+                    rc3 = KHttpFileTimedReadLocked ( self, pos, buffer, bsize, num_read, tm, & http_status );
+                    if ( rc3 == 0 )
                     {
                         DBGMSG ( DBG_KNS, DBG_FLAG ( DBG_KNS_HTTP ), ( "KHttpFileTimedRead: reopened successfully\n" ) );
                         rc= 0;
@@ -1332,15 +1343,16 @@ static rc_t KNSManagerVMakeHttpFileIntUnstableImpl( const KNSManager *self,
 
             if ( rc == 0 )
             {
-                KDataBuffer * buf = & f -> orig_url_buffer;
+                KDataBuffer * buf_f = & f -> orig_url_buffer;
                 KClientHttp *http;
-                rc = KNSManagerMakeClientHttpInt ( self, & http, buf, conn, vers,
+                rc = KNSManagerMakeClientHttpInt ( self, & http, buf_f, conn,
+                    vers, self -> conn_timeout,
                     self -> http_read_timeout, self -> http_write_timeout, & f -> block . host, f -> block . port, reliable, f -> block . tls );
                 if ( rc == 0 )
                 {
                     KClientHttpRequest *req;
 
-                    rc = KClientHttpMakeRequestInt ( http, & req, & f -> block, buf );
+                    rc = KClientHttpMakeRequestInt ( http, & req, & f -> block, buf_f );
                     if ( rc == 0 )
                     {
                         KClientHttpResult *rslt;
@@ -1377,7 +1389,7 @@ static rc_t KNSManagerVMakeHttpFileIntUnstableImpl( const KNSManager *self,
                                     "Failed to KClientHttpRequestHEAD("
                                     "'$(path)' ($(ip))) from '$(local)'",
                                     "path=%.*s,ip=%s,local=%s",
-                                    buf -> elem_count - 1, buf -> base,
+                                    buf_f -> elem_count - 1, buf_f -> base,
                                     ep . ip_address, local_ep . ip_address ) );
                             }
                         }
@@ -1420,7 +1432,8 @@ static rc_t KNSManagerVMakeHttpFileIntUnstableImpl( const KNSManager *self,
                                     rc = RC ( rcNS, rcFile, rcOpening, rcFile, rcNotFound );
                                     break;
                                 default:
-                                    rc = RC ( rcNS, rcFile, rcValidating, rcNoObj, rcEmpty );
+                                    rc = RC ( rcNS, rcFile, rcOpening, rcFile,
+                                        rcUnexpected );
                                 }
 
                                 if ( rc == 0 )
@@ -1452,15 +1465,15 @@ static rc_t KNSManagerVMakeHttpFileIntUnstableImpl( const KNSManager *self,
                                     KClientHttpGetLocalEndpoint  ( http, & local_ep );
                                     KClientHttpGetRemoteEndpoint ( http, & ep );
                                     if ( KNSManagerLogNcbiVdbNetError ( self ) ) {
-                                        char * base = buf -> base;
+                                        char * base = buf_f -> base;
                                         bool print = true;
-                                        char * query = string_chr ( base, buf -> elem_count, '?' );
+                                        char * query = string_chr ( base, buf_f -> elem_count, '?' );
                                         String vdbcache;
                                         CONST_STRING ( & vdbcache, ".vdbcache" );
-                                        if ( buf -> elem_count > vdbcache . size ) {
+                                        if ( buf_f -> elem_count > vdbcache . size ) {
                                             String ext;
                                             StringInit ( & ext,
-                                                    base + buf -> elem_count - vdbcache . size - 1,
+                                                    base + buf_f -> elem_count - vdbcache . size - 1,
                                                     vdbcache . size, vdbcache . len );
                                             if ( ext . addr [ ext . size ] == '\0' &&
                                                 StringEqual ( & vdbcache, & ext ) )
@@ -1468,9 +1481,10 @@ static rc_t KNSManagerVMakeHttpFileIntUnstableImpl( const KNSManager *self,
                                                 print = false;
                                             }
                                             else if ( query != NULL ) {
-                                                size_t size = query - base;
+                                                assert ( FITS_INTO_SIZE_T ( query - base ) );
+                                                size_t size2 = (size_t)(query - base);
                                                 StringInit ( & ext,
-                                                    base + size - vdbcache . size,
+                                                    base + size2 - vdbcache . size,
                                                     vdbcache . size, vdbcache . len );
                                                 if ( ext . addr [ ext . size ] == '?' &&
                                                     StringEqual ( & vdbcache, & ext ) )
@@ -1482,12 +1496,12 @@ static rc_t KNSManagerVMakeHttpFileIntUnstableImpl( const KNSManager *self,
                                         if ( ! reliable )
                                             print = false;
                                         if ( print ) {
-                                           assert ( buf );
+                                           assert ( buf_f );
                                            PLOGERR ( klogErr,
                                             ( klogErr, rc,
                                             "Failed to KNSManagerVMakeHttpFileInt('$(path)' ($(ip)))"
                                             " from '$(local)'", "path=%.*s,ip=%s,local=%s",
-                                            ( int ) buf -> elem_count, buf -> base,
+                                            ( int ) buf_f -> elem_count, buf_f -> base,
                                             ep . ip_address, local_ep . ip_address
                                             ) );
                                         }
@@ -1495,7 +1509,7 @@ static rc_t KNSManagerVMakeHttpFileIntUnstableImpl( const KNSManager *self,
                                     else
                                         DBGMSG ( DBG_KNS, DBG_FLAG ( DBG_KNS_HTTP ),
                                             ( "Failed to KNSManagerVMakeHttpFileInt('%.*s' (%s))\n",
-                                            ( int ) buf -> elem_count, buf -> base,
+                                            ( int ) buf_f -> elem_count, buf_f -> base,
                                             ep . ip_address ) );
                                 }
                             }
