@@ -31,20 +31,19 @@
 #include <kns/tls.h>
 #endif
 
+/* TODO: check if this if-else-endif is needed */
 #if ! defined ( MBEDTLS_CONFIG_FILE )
-#include <mbedtls/config.h>
 #else
-#include MBEDTLS_CONFIG_FILE 
+#include MBEDTLS_CONFIG_FILE
 #endif
 
-#include <mbedtls/net.h>
+#include <mbedtls/net_sockets.h>
 #include <mbedtls/debug.h>
 #include <mbedtls/ssl.h>
 #include <mbedtls/aes.h>
 #include <mbedtls/entropy.h>
 #include <mbedtls/ctr_drbg.h>
 #include <mbedtls/error.h>
-#include <mbedtls/certs.h>
 
 #ifdef __cplusplus
 extern "C" {
