@@ -35,6 +35,7 @@
 #endif
 
 #include <klib/rc.h>
+#include <klib/text.h>
 #include <sstream>
 #include <csignal>
 #include <cstdlib>
@@ -84,7 +85,7 @@ string TestEnv::lastLocation = "<init>";
 LogLevel::E TestEnv::verbosity = LogLevel::e_error;
 bool TestEnv::verbositySet = false;
 
-void CC TestEnv::TermHandler()
+void CC TestEnv::TermHandler() noexcept
 {
     SigHandler(SIGTERM);
 }
@@ -154,11 +155,11 @@ OptDef Options[] = {
 
 rc_t TestEnv::process_args(int argc, char* argv[], ArgsHandler* argsHandler)
 {
-    int arg2 = 9;
+    size_t arg2 = 9;
     argv2 = static_cast<char**>(calloc(arg2, sizeof *argv2));
     if (argv2 == NULL)
     {   return RC (rcApp, rcArgv, rcAccessing, rcMemory, rcExhausted); }
-    argv2[argc2] = strdup(argv[argc2]);
+    argv2[argc2] = string_dup_measure(argv[argc2], NULL);
     if (argv2[argc2] == NULL)
     {   return RC (rcApp, rcArgv, rcAccessing, rcMemory, rcExhausted); }
     ++argc2;
@@ -373,7 +374,7 @@ rc_t TestEnv::process_args(int argc, char* argv[], ArgsHandler* argsHandler)
             }
             char* pch = strtok(a ," ");
             while (pch != NULL) {
-                if (argc2 >= arg2) {
+                if ( (size_t)argc2 >= arg2 ) {
                     arg2 *= 2;
                     char** tmp = static_cast<char**>(
                         realloc(argv2, arg2 * sizeof *argv2));
@@ -383,7 +384,7 @@ rc_t TestEnv::process_args(int argc, char* argv[], ArgsHandler* argsHandler)
                     }
                     argv2 = tmp;
                 }
-                argv2[argc2] = strdup(pch);
+                argv2[argc2] = string_dup_measure(pch, NULL);
                 if (argv2[argc2] == NULL) {
                     return RC(
                         rcApp, rcArgv, rcAccessing, rcMemory, rcExhausted);
@@ -393,7 +394,7 @@ rc_t TestEnv::process_args(int argc, char* argv[], ArgsHandler* argsHandler)
             }
         }
         else {
-            if ( argc2 >= arg2 ) {
+            if ( (size_t)argc2 >= arg2 ) {
                 arg2 *= 2;
                 char ** tmp = static_cast < char ** > (
                     realloc ( argv2, arg2 * sizeof *argv2 ) );
@@ -402,7 +403,7 @@ rc_t TestEnv::process_args(int argc, char* argv[], ArgsHandler* argsHandler)
                         rcApp, rcArgv, rcAccessing, rcMemory, rcExhausted );
                 argv2 = tmp;
             }
-            argv2 [ argc2 ] = strdup ( argv [ i ] );
+            argv2 [ argc2 ] = string_dup_measure ( argv [ i ], NULL );
             if ( argv2 [ argc2 ] == NULL )
                 return RC ( rcApp, rcArgv, rcAccessing, rcMemory, rcExhausted );
             ++ argc2;
@@ -429,7 +430,7 @@ rc_t TestEnv::process_args(int argc, char* argv[], ArgsHandler* argsHandler)
 }
 
 std::mutex saveLocation_mtx;
-void ::ncbi::NK::saveLocation(const char* file, int line)
+void ::ncbi::NK::saveLocation(const char* file, unsigned int line)
 {
     std::ostringstream s;
     s << file << "(" << line << ")";
@@ -438,7 +439,7 @@ void ::ncbi::NK::saveLocation(const char* file, int line)
     saveLocation_mtx.unlock();
 }
 
-void ::ncbi::NK::_REPORT_CRITICAL_ERROR_(const string& msg, const char* file, int line, bool is_msg)
+void ::ncbi::NK::_REPORT_CRITICAL_ERROR_(const string& msg, const char* file, unsigned int line, bool is_msg)
 {
     LOG(ncbi::NK::LogLevel::e_error, file << "(" << line << "): ");
     LOG(ncbi::NK::LogLevel::e_error, "fatal ");
