@@ -37,25 +37,26 @@ using namespace ncbi::SchemaParser;
 
 using namespace std;
 
-ASTBuilder :: ASTBuilder ( VSchema * p_schema )
+ASTBuilder :: ASTBuilder ( ctx_t ctx, VSchema * p_schema )
 :   m_schema ( p_schema ),
     m_nextContextId ( 0 ),
     m_view ( 0 )
 {
+    FUNC_ENTRY( ctx, rcSRA, rcSchema, rcParsing );
     assert ( m_schema != 0 );
     VSchemaAddRef ( m_schema );
 
     rc_t rc = KSymTableInit ( & m_symtab, 0 );
     if ( rc != 0 )
     {
-        ReportRc ( "KSymTableInit", rc );
+        ReportRc ( ctx, "KSymTableInit", rc );
     }
     else
     {
         rc = init_symtab ( & m_symtab, m_schema ); // this pushes the global scope
         if ( rc != 0 )
         {
-            ReportRc ( "init_symtab", rc );
+            ReportRc ( ctx, "init_symtab", rc );
         }
     }
 }
@@ -67,79 +68,81 @@ ASTBuilder :: ~ASTBuilder ()
 }
 
 void
-ASTBuilder :: ReportError ( const ErrorReport :: Location & p_loc, const char * p_msg )
+ASTBuilder :: ReportError ( ctx_t ctx, const ErrorReport :: Location & p_loc, const char * p_msg )
 {
-    m_errors . ReportError ( p_loc, "%s", p_msg );
+    FUNC_ENTRY( ctx, rcSRA, rcSchema, rcParsing );
+    m_errors . ReportError ( ctx, p_loc, "%s", p_msg );
 }
 
 void
-ASTBuilder :: ReportError ( const char * p_msg, const AST_FQN& p_fqn )
+ASTBuilder :: ReportError ( ctx_t ctx, const char * p_msg, const AST_FQN& p_fqn )
 {
+    FUNC_ENTRY( ctx, rcSRA, rcSchema, rcParsing );
     char buf [ 1024 ];
     p_fqn . GetFullName ( buf, sizeof buf );
-    m_errors . ReportError ( p_fqn . GetChild ( 0 ) -> GetToken () . GetLocation (), "%s: '%s'", p_msg, buf );
+    m_errors . ReportError ( ctx, p_fqn . GetChild ( 0 ) -> GetToken () . GetLocation (), "%s: '%s'", p_msg, buf );
     //TODO: add location of the original declaration
 }
 
 void
-ASTBuilder :: ReportError ( const ErrorReport :: Location & p_loc, const char * p_msg, const String & p_str )
+ASTBuilder :: ReportError ( ctx_t ctx, const ErrorReport :: Location & p_loc, const char * p_msg, const String & p_str )
 {
-    m_errors . ReportError ( p_loc, "%s: '%S'", p_msg, & p_str );
+    FUNC_ENTRY( ctx, rcSRA, rcSchema, rcParsing );
+    m_errors . ReportError ( ctx, p_loc, "%s: '%S'", p_msg, & p_str );
 }
 
 void
-ASTBuilder :: ReportError ( const ErrorReport :: Location & p_loc, const char * p_msg, const char * p_str )
+ASTBuilder :: ReportError ( ctx_t ctx, const ErrorReport :: Location & p_loc, const char * p_msg, const char * p_str )
 {
-    m_errors . ReportError ( p_loc, "%s: '%s'", p_msg, p_str );
+    FUNC_ENTRY( ctx, rcSRA, rcSchema, rcParsing );
+    m_errors . ReportError ( ctx, p_loc, "%s: '%s'", p_msg, p_str );
 }
 
 void
-ASTBuilder :: ReportError ( const ErrorReport :: Location & p_loc, const char * p_msg, int64_t p_val )
+ASTBuilder :: ReportError ( ctx_t ctx, const ErrorReport :: Location & p_loc, const char * p_msg, int64_t p_val )
 {
-    m_errors . ReportError ( p_loc, "%s: %l", p_msg, p_val );
+    FUNC_ENTRY( ctx, rcSRA, rcSchema, rcParsing );
+    m_errors . ReportError ( ctx, p_loc, "%s: %l", p_msg, p_val );
 }
 
 void
-ASTBuilder :: ReportRc ( const char* p_msg, rc_t p_rc )
+ASTBuilder :: ReportRc ( ctx_t ctx, const char* p_msg, rc_t p_rc )
 {
-    m_errors . ReportInternalError ( "", "%s: rc=%R", p_msg, p_rc );
-}
-
-void
-ASTBuilder :: ReportInternalError ( const char * p_msg, const char * p_source )
-{
-    m_errors . ReportInternalError ( p_source, "%s", p_msg );
+    INTERNAL_ERROR ( xcUnexpected, "%s: rc=%R", p_msg, p_rc );
 }
 
 AST *
-ASTBuilder :: Build ( const ParseTree& p_root, const char * p_source, bool p_debugParse )
+ASTBuilder :: Build ( ctx_t ctx, const ParseTree& p_root, const char * p_source, bool p_debugParse )
 {
+    FUNC_ENTRY( ctx, rcSRA, rcSchema, rcParsing );
     AST* ret = 0;
     AST_debug = p_debugParse;
-    ParseTreeScanner scanner ( p_root, p_source );
-    if ( AST_parse ( ret, * this, scanner ) == 0 )
+    ParseTreeScanner scanner ( ctx, p_root, p_source );
+    if ( AST_parse ( ctx, ret, * this, scanner ) == 0 )
     {
         return ret;
     }
-    delete ret;
+    AST :: Destroy ( ret );
     return 0;
 }
 
 bool
-ASTBuilder :: VectorAppend ( Vector & p_self, uint32_t *p_idx, const void *p_item )
+ASTBuilder :: VectorAppend ( ctx_t ctx, Vector & p_self, uint32_t *p_idx, const void *p_item )
 {
+    FUNC_ENTRY( ctx, rcSRA, rcSchema, rcParsing );
     rc_t rc = :: VectorAppend ( & p_self, p_idx, p_item );
     if ( rc != 0 )
     {
-        ReportRc ( "VectorAppend", rc );
+        ReportRc ( ctx, "VectorAppend", rc );
         return false;
     }
     return true;
 }
 
 const KSymbol*
-ASTBuilder :: CreateFqnSymbol ( const AST_FQN& p_fqn, uint32_t p_type, const void * p_obj )
+ASTBuilder :: CreateFqnSymbol ( ctx_t ctx, const AST_FQN& p_fqn, uint32_t p_type, const void * p_obj )
 {
+    FUNC_ENTRY( ctx, rcSRA, rcSchema, rcParsing );
     rc_t rc = 0;
     uint32_t count = p_fqn . NamespaceCount ();
     for ( uint32_t i = 0 ; i < count; ++ i )
@@ -154,12 +157,12 @@ ASTBuilder :: CreateFqnSymbol ( const AST_FQN& p_fqn, uint32_t p_type, const voi
             rc = KSymTablePushNamespace ( & m_symtab, ns );
             if ( rc != 0 )
             {
-                ReportRc ( "KSymTablePushNamespace", rc );
+                ReportRc ( ctx, "KSymTablePushNamespace", rc );
             }
         }
         else
         {
-            ReportRc ( "KSymTableCreateNamespace", rc );
+            ReportRc ( ctx, "KSymTableCreateNamespace", rc );
         }
     }
 
@@ -172,11 +175,11 @@ ASTBuilder :: CreateFqnSymbol ( const AST_FQN& p_fqn, uint32_t p_type, const voi
         rc = KSymTableCreateSymbol ( & m_symtab, & ret, & name, p_type, p_obj );
         if ( GetRCState ( rc ) == rcExists )
         {
-            ReportError ( "Object already declared", p_fqn );
+            ReportError ( ctx, "Object already declared", p_fqn );
         }
         else if ( rc != 0 )
         {
-            ReportRc ( "KSymTableCreateSymbol", rc );
+            ReportRc ( ctx, "KSymTableCreateSymbol", rc );
         }
     }
 
@@ -189,92 +192,136 @@ ASTBuilder :: CreateFqnSymbol ( const AST_FQN& p_fqn, uint32_t p_type, const voi
 }
 
 KSymbol*
-ASTBuilder :: Resolve ( const Token :: Location & p_loc, const char* p_ident, bool p_reportUnknown )
+ASTBuilder :: Resolve ( ctx_t ctx, const Token :: Location & p_loc, const char* p_ident, bool p_reportUnknown )
 {
+    FUNC_ENTRY( ctx, rcSRA, rcSchema, rcParsing );
     String name;
     StringInitCString ( & name, p_ident );
     KSymbol* ret = KSymTableFind ( & m_symtab, & name );
     if ( ret == 0 && p_reportUnknown )
     {
-        ReportError ( p_loc, "Undeclared identifier", p_ident );
+        ReportError ( ctx, p_loc, "Undeclared identifier", p_ident );
     }
     return ret;
 }
 
 const KSymbol*
-ASTBuilder :: Resolve ( const AST_FQN & p_fqn, bool p_reportUnknown )
+ASTBuilder :: ResolveNestedName ( ctx_t ctx, const AST_FQN & p_fqn, uint32_t p_idx, uint32_t & p_missingIdx )
 {
+    FUNC_ENTRY( ctx, rcSRA, rcSchema, rcParsing );
+    const KSymbol* ret = 0;
+    String name;
+    StringInitCString ( & name, p_fqn . GetChild ( p_idx ) -> GetTokenValue () );
+    if ( p_idx == p_fqn . ChildrenCount () - 1 )
+    {   // we pushed all the namespaces; if all of them existed we can look for the identifier in the innermost namespace
+        ret = KSymTableFindShallow ( & m_symtab, & name );
+        if ( ret == 0 )
+        {   // for error reporting, specify which of the names in the chain was not found
+            p_missingIdx = p_idx;
+        }
+    }
+    else
+    {   // we are still inside the chain of namespaces
+        KSymbol *ns = KSymTableFindShallow ( & m_symtab, & name );
+        rc_t rc;
+        if ( ns == 0 )
+        {   // create a new namespace
+            rc = KSymTableCreateNamespace ( & m_symtab, & ns, & name );
+            if ( rc != 0 )
+            {
+                ReportRc ( ctx, "KSymTableCreateNamespace", rc );
+                return 0;
+            }
+        }
+        rc = KSymTablePushNamespace ( & m_symtab, ns );
+        if ( rc != 0 )
+        {
+            ReportRc ( ctx, "KSymTablePushNamespace", rc );
+            return 0;
+        }
+        ret = ResolveNestedName ( ctx, p_fqn, p_idx + 1, p_missingIdx );
+        KSymTablePopNamespace ( & m_symtab );
+    }
+
+    return ret;
+}
+
+const KSymbol*
+ASTBuilder :: Resolve ( ctx_t ctx, const AST_FQN & p_fqn, bool p_reportUnknown )
+{
+    FUNC_ENTRY( ctx, rcSRA, rcSchema, rcParsing );
+    rc_t rc = 0;
     uint32_t count = p_fqn . ChildrenCount ();
     assert ( count > 0 );
 
     if ( count == 1 )
     {   // plain identifier
-        return Resolve ( p_fqn .GetLocation (), p_fqn . GetChild ( 0 ) -> GetTokenValue (), p_reportUnknown );
+        return Resolve ( ctx, p_fqn .GetLocation (), p_fqn . GetChild ( 0 ) -> GetTokenValue (), p_reportUnknown );
     }
 
-    // work the namespaces
-    bool ns_resolved = true;
-    for ( uint32_t i = 0 ; i < count - 1; ++ i )
-    {
-        String name;
-        StringInitCString ( & name, p_fqn . GetChild ( i ) -> GetTokenValue () );
-        KSymbol *ns = 0;
-        if ( i == 0 )
-        {
-            ns = KSymTableFindGlobal ( & m_symtab, & name );
-        }
-        else if ( ns_resolved )
-        {
-            ns = KSymTableFindShallow ( & m_symtab, & name );
-        }
-
-        if ( ns == 0 )
-        {
-            ns_resolved = false; // no need to do any lookup from now on
-            // create a new namespace
-            rc_t rc = KSymTableCreateNamespace ( & m_symtab, & ns, & name );
-            if ( rc != 0 )
-            {
-                ReportRc ( "KSymTableCreateNamespace", rc );
-                count = i;
-                break;
-            }
-        }
-
-        rc_t rc = KSymTablePushNamespace ( & m_symtab, ns );
-        if ( rc != 0 )
-        {
-            ReportRc ( "KSymTablePushNamespace", rc );
-            count = i;
-            ns_resolved = false;
-            break;
-        }
-    }
-
-    // we pushed all the namespaces; if all of them existed we can look for the identifier in the innermost namespace
-    String name;
-    p_fqn . GetIdentifier ( name );
-
     const KSymbol * ret = 0;
-    if ( ns_resolved )
-    {
-        ret = KSymTableFindShallow ( & m_symtab, & name );
-    }
-    if ( ret == 0 && p_reportUnknown )
-    {
-        ReportError ( p_fqn . GetChild ( p_fqn . ChildrenCount () - 1 ) -> GetLocation (), "Undeclared identifier", name );
-    }
-
-    // pop the namespaces, count is how many to pop
-    if ( count > 0 )
-    {
-        for ( uint32_t i = 0 ; i < count - 1; ++ i )
+    uint32_t missingIdx = 0;
+    // resolve the outer namespace
+    String name;
+    StringInitCString ( & name, p_fqn . GetChild ( 0 ) -> GetTokenValue () );
+    KSymbol * ns = KSymTableFind ( & m_symtab, & name );
+    if ( ns == 0 )
+    {   // create a new namespace
+        rc = KSymTableCreateNamespace ( & m_symtab, & ns, & name );
+        if ( rc != 0 )
         {
-            KSymTablePopNamespace ( & m_symtab );
+            ReportRc ( ctx, "KSymTableCreateNamespace", rc );
+            return 0;
         }
     }
 
-    return ret;
+    rc = KSymTablePushNamespace ( & m_symtab, ns );
+    if ( rc != 0 )
+    {
+        ReportRc ( ctx, "KSymTablePushNamespace", rc );
+        KSymTablePopNamespace ( & m_symtab );
+        return 0;
+    }
+
+    ret = ResolveNestedName ( ctx, p_fqn, 1, missingIdx );
+    KSymTablePopNamespace ( & m_symtab );
+    if ( ret != 0 )
+    {
+        return ret;
+    }
+
+    /* before returning an error, look harder.
+        extended VSchema can create symtab entries
+        for namespaces that opaque the parent schema */
+    uint32_t scope = 0;
+    while ( ns != 0 )
+    {
+        /* find a deeper symbol */
+        ns = KSymTableFindNext ( & m_symtab, ns, & scope );
+        if ( ns != NULL && ns -> type == eNamespace )
+        {
+            rc = KSymTablePushNamespace ( & m_symtab, ns );
+            if ( rc != 0 )
+            {
+                ReportRc ( ctx, "KSymTablePushNamespace", rc );
+                KSymTablePopNamespace ( & m_symtab );
+                return 0;
+            }
+            ret = ResolveNestedName ( ctx, p_fqn, 1, missingIdx );
+            KSymTablePopNamespace ( & m_symtab );
+            if ( ret != 0 )
+            {
+                return ret;
+            }
+        }
+    }
+
+    if ( p_reportUnknown )
+    {
+        const AST * missing = p_fqn . GetChild ( missingIdx );
+        ReportError ( ctx, missing -> GetLocation (), "Undeclared identifier", missing -> GetTokenValue () );
+    }
+    return 0;
 }
 
 uint32_t
@@ -290,10 +337,11 @@ ASTBuilder :: IntrinsicTypeId ( const char * p_type ) const
 }
 
 uint64_t
-ASTBuilder :: EvalConstExpr ( const AST_Expr & p_expr )
+ASTBuilder :: EvalConstExpr ( ctx_t ctx, const AST_Expr & p_expr )
 {
+    FUNC_ENTRY( ctx, rcSRA, rcSchema, rcParsing );
     uint64_t ret = 0;
-    SExpression * expr = p_expr . EvaluateConst ( *this ); // will report problems
+    SExpression * expr = p_expr . EvaluateConst ( ctx, *this ); // will report problems
     if ( expr != 0 )
     {
         switch ( expr -> var )
@@ -307,7 +355,7 @@ ASTBuilder :: EvalConstExpr ( const AST_Expr & p_expr )
             }
             break;
         default:
-            ReportError ( p_expr . GetLocation (), "Unsupported in const expressions", expr -> var );
+            ReportError ( ctx, p_expr . GetLocation (), "Unsupported in const expressions", expr -> var );
             break;
         }
         SExpressionWhack ( expr );
@@ -316,11 +364,13 @@ ASTBuilder :: EvalConstExpr ( const AST_Expr & p_expr )
 }
 
 const void *
-ASTBuilder :: SelectVersion ( const AST_FQN & p_fqn,
+ASTBuilder :: SelectVersion ( ctx_t ctx,
+                              const AST_FQN & p_fqn,
                               const KSymbol & p_ovl,
-                              int64_t ( CC * p_cmp ) ( const void *item, const void *n ),
+                              int64_t ( CC * p_cmp ) ( const void *item, const void *n ) noexcept,
                               uint32_t * p_version )
 {
+    FUNC_ENTRY( ctx, rcSRA, rcSchema, rcParsing );
     const SNameOverload *name = static_cast < const SNameOverload * > ( p_ovl . u . obj );
     const void * ret = 0;
     uint32_t version = p_fqn . GetVersion ();
@@ -329,7 +379,8 @@ ASTBuilder :: SelectVersion ( const AST_FQN & p_fqn,
         ret = VectorFind ( & name -> items, & version, NULL, p_cmp );
         if ( ret == 0 )
         {
-            m_errors . ReportError ( p_fqn . GetLocation (),
+            m_errors . ReportError ( ctx,
+                                     p_fqn . GetLocation (),
                                      "Requested version does not exist: '%S#%V'",
                                      & p_ovl . name, version );
         }
@@ -346,21 +397,22 @@ ASTBuilder :: SelectVersion ( const AST_FQN & p_fqn,
 }
 
 KSymbol *
-ASTBuilder :: CreateLocalSymbol ( const AST & p_node, const String & p_name, int p_type, const void * p_obj )
+ASTBuilder :: CreateLocalSymbol ( ctx_t ctx, const AST & p_node, const String & p_name, int p_type, const void * p_obj )
 {
+    FUNC_ENTRY( ctx, rcSRA, rcSchema, rcParsing );
     KSymbol * ret = 0;
 
     if ( KSymTableFindShallow ( & GetSymTab (), & p_name ) != 0 ||
             KSymTableFindIntrinsic ( & GetSymTab (), & p_name ) )
     {
-        ReportError ( p_node . GetLocation (), "Name already in use", p_name );
+        ReportError ( ctx, p_node . GetLocation (), "Name already in use", p_name );
     }
     else
     {
         rc_t rc = KSymTableCreateSymbol ( & GetSymTab (), & ret, & p_name, p_type, p_obj );
         if ( rc != 0 )
         {
-            ReportRc ( "KSymTableCreateSymbol", rc );
+            ReportRc ( ctx, "KSymTableCreateSymbol", rc );
         }
     }
 
@@ -368,46 +420,49 @@ ASTBuilder :: CreateLocalSymbol ( const AST & p_node, const String & p_name, int
 }
 
 KSymbol *
-ASTBuilder :: CreateLocalSymbol ( const AST & p_node, const char* p_name, int p_type, const void * p_obj )
+ASTBuilder :: CreateLocalSymbol ( ctx_t ctx, const AST & p_node, const char* p_name, int p_type, const void * p_obj )
 {
     String name;
     StringInitCString ( & name, p_name );
-    return CreateLocalSymbol ( p_node, name, p_type, p_obj );
+    return CreateLocalSymbol ( ctx, p_node, name, p_type, p_obj );
 }
 
 KSymbol *
-ASTBuilder :: CreateConstSymbol ( const char* p_name, int p_type, const void * p_obj )
+ASTBuilder :: CreateConstSymbol ( ctx_t ctx, const char* p_name, int p_type, const void * p_obj )
 {
+    FUNC_ENTRY( ctx, rcSRA, rcSchema, rcParsing );
     KSymbol * ret = 0;
     String name;
     StringInitCString ( & name, p_name );
     rc_t rc = KSymTableCreateConstSymbol ( & GetSymTab (), & ret, & name, p_type, p_obj );
     if ( rc != 0 )
     {
-        ReportRc ( "KSymTableCreateSymbol", rc );
+        ReportRc ( ctx, "KSymTableCreateSymbol", rc );
     }
     return ret;
 }
 
 bool
-ASTBuilder :: CreateOverload ( const KSymbol *  p_name,
+ASTBuilder :: CreateOverload ( ctx_t ctx,
+                               const KSymbol &  p_name,
                                const void *     p_object,
-                               int64_t          (CC *p_sort)(const void *, const void *),
+                               uint32_t         p_context_type,
+                               int64_t          (CC *p_sort)(const void *, const void *) noexcept,
                                Vector &         p_objects,
                                Vector &         p_names,
-                               uint32_t *       p_id )
+                               uint32_t &       p_id )
 {
-    assert ( p_name != 0 );
+    FUNC_ENTRY( ctx, rcSRA, rcSchema, rcParsing );
     SNameOverload * ovl;
-    rc_t rc = SNameOverloadMake ( & ovl, p_name, 0, 4 );
+    rc_t rc = SNameOverloadMake ( & ovl, & p_name, p_context_type, 0, 4 );
     if ( rc == 0 )
     {
         rc = VectorInsertUnique ( & ovl -> items, p_object, 0, p_sort );
         if ( rc == 0 )
         {
-            if ( VectorAppend ( p_objects, p_id, p_object ) )
+            if ( VectorAppend ( ctx, p_objects, & p_id, p_object ) )
             {
-                if ( VectorAppend ( p_names, & ovl -> cid . id, ovl ) )
+                if ( VectorAppend ( ctx, p_names, & ovl -> cid . id, ovl ) )
                 {
                     ovl -> cid . ctx = -1;
                     return true;
@@ -416,26 +471,27 @@ ASTBuilder :: CreateOverload ( const KSymbol *  p_name,
         }
         else
         {
-            ReportRc ( "VectorInsertUnique", rc );
+            ReportRc ( ctx, "VectorInsertUnique", rc );
         }
         SNameOverloadWhack ( ovl, 0 );
     }
     else
     {
-        ReportRc ( "SNameOverloadMake", rc );
+        ReportRc ( ctx, "SNameOverloadMake", rc );
     }
     return false;
 }
 
 void
-ASTBuilder :: AddProduction ( const AST & p_node, Vector & p_list, const char * p_name, const AST_Expr & p_expr, const AST * p_type )
+ASTBuilder :: AddProduction ( ctx_t ctx, const AST & p_node, Vector & p_list, const char * p_name, const AST_Expr & p_expr, const AST * p_type )
 {
-    SProduction * prod = Alloc < SProduction > ();
+    FUNC_ENTRY( ctx, rcSRA, rcSchema, rcParsing );
+    SProduction * prod = Alloc < SProduction > ( ctx );
     if ( prod != 0 )
     {
         if ( p_type != 0 )
         {
-            STypeExpr * type = MakeTypeExpr ( * p_type );
+            STypeExpr * type = MakeTypeExpr ( ctx, * p_type );
             if ( type != 0 )
             {
                 prod -> fd = & type -> dad;
@@ -446,14 +502,14 @@ ASTBuilder :: AddProduction ( const AST & p_node, Vector & p_list, const char *
             prod -> trigger = true;
         }
 
-        prod -> name = Resolve ( p_node . GetLocation (), p_name, false );
+        prod -> name = Resolve ( ctx, p_node . GetLocation (), p_name, false );
         if ( prod -> name == 0 )
         {
-            prod -> name = CreateLocalSymbol ( p_node, p_name, eProduction, prod );
+            prod -> name = CreateLocalSymbol ( ctx, p_node, p_name, eProduction, prod );
         }
         else if ( prod -> name -> type != eForward && prod -> name -> type != eVirtual )
         {
-            ReportError ( p_node . GetLocation (), "Production name is already in use", p_name );
+            ReportError ( ctx, p_node . GetLocation (), "Production name is already in use", p_name );
             SProductionWhack ( prod, NULL );
             return;
         }
@@ -461,12 +517,19 @@ ASTBuilder :: AddProduction ( const AST & p_node, Vector & p_list, const char *
         sym -> type = eProduction;
         sym -> u . obj = prod;
 
-        prod -> expr = p_expr . MakeExpression ( *this ) ;
-
-        if ( ! VectorAppend ( p_list, & prod -> cid . id, prod ) )
-        {
+        prod -> expr = p_expr . MakeExpression ( ctx, *this ) ;
+        if ( prod -> expr == 0 )
+        {   // semantic error in the rhs
             SProductionWhack ( prod, NULL );
         }
+        else
+        {
+            prod -> cid . ctx = 1;  /* ctx = 0 for params, ctx == 1 for productions */
+            if ( ! VectorAppend ( ctx, p_list, & prod -> cid . id, prod ) )
+            {
+                SProductionWhack ( prod, NULL );
+            }
+        }
     }
 }
 
@@ -493,8 +556,9 @@ ASTBuilder :: CheckForColumnCollision ( const KSymbol *sym )
 }
 
 bool
-ASTBuilder :: ScanVirtuals ( const Token :: Location & p_loc, Vector & p_byParent )
+ASTBuilder :: ScanVirtuals ( ctx_t ctx, const Token :: Location & p_loc, Vector & p_byParent, KSymTable & p_symtab )
 {
+    FUNC_ENTRY( ctx, rcSRA, rcSchema, rcParsing );
     uint32_t start = VectorStart ( & p_byParent );
     uint32_t count = VectorLength ( & p_byParent );
     for ( uint32_t i = 0; i < count; ++ i )
@@ -508,7 +572,7 @@ ASTBuilder :: ScanVirtuals ( const Token :: Location & p_loc, Vector & p_byParen
 
             /* since the virtual productions in one parent could be
                defined by another parent, test for the possibility */
-            const KSymbol *def = KSymTableFindSymbol ( & GetSymTab (), orig );
+            const KSymbol *def = KSymTableFindSymbol ( & p_symtab, orig );
             if ( def != NULL )
             {
                 if ( def -> type == eProduction || def -> type == eVirtual )
@@ -517,7 +581,8 @@ ASTBuilder :: ScanVirtuals ( const Token :: Location & p_loc, Vector & p_byParen
                 }
                 else
                 {
-                    ReportError ( p_loc,
+                    ReportError ( ctx,
+                                  p_loc,
                                   "a virtual production from one parent defined as non-production in another",
                                   def -> name );
                     return false;
@@ -526,12 +591,12 @@ ASTBuilder :: ScanVirtuals ( const Token :: Location & p_loc, Vector & p_byParen
             else
             {
                 /* copy the original */
-                BSTree * scope = static_cast < BSTree * > ( VectorLast ( & GetSymTab () . stack ) );
+                BSTree * scope = static_cast < BSTree * > ( VectorLast ( & p_symtab . stack ) );
                 const KSymbol *copy;
                 rc_t rc = KSymbolCopy ( scope, & copy, orig );
                 if ( rc != 0 )
                 {
-                    ReportRc ( "KSymbolCopy", rc );
+                    ReportRc ( ctx, "KSymbolCopy", rc );
                     return false;
                 }
 
