@@ -56,29 +56,11 @@
  *  opaque handle to library
  */
 
-LIB_EXPORT rc_t CC VDBManagerMakeWithVFSManager(const VDBManager ** mgrp,
-    const KDirectory *wd, struct VFSManager *vmgr)
+static
+rc_t
+VDBManagerMakeRead_Int ( const VDBManager ** mgrp, const struct KDBManager *kdbmgr )
 {
-    return VDBManagerMakeReadWithVFSManager(mgrp, wd, NULL);
-}
-
-/* MakeRead
- * MakeReadWithVFSManager
- *  create library handle for specific use
- *  NB - only one of the functions will be implemented
- *
- *  "wd" [ IN, NULL OKAY ] - optional working directory for
- *  accessing the file system. mgr will attach its own reference.
- */
-LIB_EXPORT rc_t CC VDBManagerMakeRead ( const VDBManager **mgrp, const KDirectory *wd )
-{
-    return VDBManagerMakeReadWithVFSManager(mgrp, wd, NULL);
-}
-
-LIB_EXPORT rc_t CC VDBManagerMakeReadWithVFSManager ( const VDBManager ** mgrp,
-    const KDirectory *wd, struct VFSManager *vmgr )
-{
-    rc_t rc;
+   rc_t rc;
 
     if ( mgrp == NULL )
         rc = RC ( rcVDB, rcMgr, rcConstructing, rcParam, rcNull );
@@ -89,32 +71,28 @@ LIB_EXPORT rc_t CC VDBManagerMakeReadWithVFSManager ( const VDBManager ** mgrp,
             rc = RC ( rcVDB, rcMgr, rcConstructing, rcMemory, rcExhausted );
         else
         {
-            rc = KDBManagerMakeReadWithVFSManager ( & mgr -> kmgr, wd, vmgr );
+            mgr -> kmgr = kdbmgr;
+
+            rc = VSchemaMakeIntrinsic ( & mgr -> schema );
             if ( rc == 0 )
             {
-                rc = VSchemaMakeIntrinsic ( & mgr -> schema );
+                rc = VLinkerMakeIntrinsic ( & mgr -> linker );
                 if ( rc == 0 )
                 {
-                    rc = VLinkerMakeIntrinsic ( & mgr -> linker );
+                    rc = VDBManagerConfigPaths ( mgr, false );
                     if ( rc == 0 )
                     {
-                        rc = VDBManagerConfigPaths ( mgr, false );
-                        if ( rc == 0 )
-                        {
-                            mgr -> user = NULL;
-                            mgr -> user_whack = NULL;
-                            KRefcountInit ( & mgr -> refcount, 1, "VDBManager", "make-read", "vmgr" );
-                            * mgrp = mgr;
-                            return 0;
-                        }
-
-                        VLinkerRelease ( mgr -> linker );
+                        mgr -> user = NULL;
+                        mgr -> user_whack = NULL;
+                        KRefcountInit ( & mgr -> refcount, 1, "VDBManager", "make-read", "vmgr" );
+                        * mgrp = mgr;
+                        return 0;
                     }
 
-                    VSchemaRelease ( mgr -> schema );
+                    VLinkerRelease ( mgr -> linker );
                 }
 
-                KDBManagerRelease ( mgr -> kmgr );
+                VSchemaRelease ( mgr -> schema );
             }
 
             free ( mgr );
@@ -125,6 +103,62 @@ LIB_EXPORT rc_t CC VDBManagerMakeReadWithVFSManager ( const VDBManager ** mgrp,
     return rc;
 }
 
+LIB_EXPORT rc_t CC VDBManagerMakeWithVFSManager(const VDBManager ** mgrp,
+    const KDirectory *wd, struct VFSManager *vmgr)
+{
+    return VDBManagerMakeReadWithVFSManager(mgrp, wd, NULL);
+}
+
+LIB_EXPORT rc_t CC VDBManagerMakeReadWithKDBManager (
+    struct VDBManager const **mgr, const struct KDBManager *kdbmgr )
+{
+    if ( mgr == NULL )
+    {
+        return SILENT_RC ( rcVDB, rcMgr, rcConstructing, rcParam, rcNull );
+    }
+    if ( kdbmgr == NULL )
+    {
+        return SILENT_RC ( rcVDB, rcMgr, rcConstructing, rcParam, rcNull );
+    }
+
+    rc_t rc = VDBManagerMakeRead_Int( mgr, kdbmgr );
+    if ( rc == 0 )
+    {
+        rc = KDBManagerAddRef( kdbmgr );
+    }
+    return rc;
+}
+
+/* MakeRead
+ * MakeReadWithVFSManager
+ *  create library handle for specific use
+ *  NB - only one of the functions will be implemented
+ *
+ *  "wd" [ IN, NULL OKAY ] - optional working directory for
+ *  accessing the file system. mgr will attach its own reference.
+ */
+
+LIB_EXPORT rc_t CC VDBManagerMakeRead ( const VDBManager **mgrp, const KDirectory *wd )
+{
+    return VDBManagerMakeReadWithVFSManager(mgrp, wd, NULL);
+}
+
+LIB_EXPORT rc_t CC VDBManagerMakeReadWithVFSManager ( const VDBManager ** mgrp,
+    const KDirectory *wd, struct VFSManager *vmgr )
+{
+    const KDBManager * kdbmgr;
+    rc_t rc = KDBManagerMakeReadWithVFSManager ( & kdbmgr, wd, vmgr );
+    if ( rc == 0 )
+    {
+        rc = VDBManagerMakeRead_Int( mgrp, kdbmgr );
+        if ( rc != 0 )
+        {
+            KDBManagerRelease( kdbmgr );
+        }
+    }
+    return rc;
+}
+
 
 /* MakeRsrc
  *  common make, regardless of library
