@@ -625,10 +625,10 @@ void SFunctionRestSchemaParms ( const SFunction *self, Vector *prior, Vector *cx
         /* restore the binding vector */
         rc = VectorSwap ( cx_bind, ic -> expr_id, cx_old, & ignore );
         assert ( rc == 0 );
+        UNUSED(rc);
 
         DBG_CXBIND2 ( "restore bind const", ic -> name -> name, ic -> expr_id, ignore, cx_old );
     }
-
     VectorWhack ( prior, NULL, NULL );
 }
 
@@ -654,6 +654,7 @@ void SFunctionRestFactParms ( const SFunction *self, Vector *prior, Vector *cx_b
         /* restore the binding vector */
         rc = VectorSwap ( cx_bind, ic -> expr_id, cx_old, & ignore );
         assert ( rc == 0 );
+        UNUSED(rc);
 
         DBG_CXBIND2 ( "restore bind const", ic -> name -> name, ic -> expr_id, ignore, cx_old );
     }
@@ -1542,7 +1543,7 @@ rc_t function_decl ( KSymTable *tbl, KTokenSource *src, KToken *t,
         if ( name == NULL )
         {
             /* create name */
-            rc = SNameOverloadMake ( & name, f -> name, 0, 4 );
+            rc = SNameOverloadMake ( & name, f -> name, 0, 0, 4 );
             if ( rc == 0 )
             {
                 /* insert it - it's allowed to be empty */
