@@ -24,8 +24,8 @@
 *
 */
 
-#ifndef _h_schema_priv_
-#define _h_schema_priv_
+#ifndef _h_libs_schema_priv_
+#define _h_libs_schema_priv_
 
 #ifndef _h_vdb_schema_
 #include <vdb/schema.h>
@@ -120,6 +120,7 @@ struct KSymTable;
 struct SchemaEnv;
 struct KFile;
 struct KDirectory;
+struct SView;
 
 /*--------------------------------------------------------------------------
  * VCtxId
@@ -131,6 +132,7 @@ struct VCtxId
 {
     uint32_t ctx;
     uint32_t id;
+    uint32_t ctx_type; /* eTable, eView etc. */
 };
 
 /* Cmp
@@ -219,9 +221,11 @@ struct SNameOverload
 };
 
 /* Make
+    ctx_type = 0 for top-level objects (table, db, function), otherwise the type of the
+    enclosing object (eTable, eView etc.)
  */
 rc_t SNameOverloadMake ( SNameOverload **name,
-    struct KSymbol const *sym, uint32_t start, uint32_t len );
+    struct KSymbol const *sym, uint32_t ctx_type, uint32_t start, uint32_t len );
 
 /* Copy
  */
@@ -1054,6 +1058,12 @@ rc_t STableDump ( const STable *self, struct SDumper *d );
  */
 rc_t CC STableExtend ( struct KSymTable *tbl, STable *self, const STable *dad );
 
+/* IsA
+ * true if p_self and p_table are the same, or p_self is derived (directly or indirectly) from p_table
+ */
+bool
+STableIsA ( const STable * p_self, const STable * p_table );
+
 /* schema_update_tbl_ref
  * updates references to a table's ancestor with the ancestor's newer version
  */
@@ -1073,7 +1083,7 @@ bool CC table_fwd_scan ( BSTNode *n, void *data );
 /* table_set_context
  * set context id on all table members
  */
-void CC table_set_context ( STable *self, uint32_t p_ctxId );
+void CC table_set_context ( STable *self );
 
 /* ScanVirtuals
  * scan override tables for virtual symbols
@@ -1262,6 +1272,9 @@ struct SDatabase
     /* tables */
     Vector tbl;
 
+    /* view aliases */
+    Vector aliases;
+
     /* required version */
     uint32_t version;
 
@@ -1354,6 +1367,44 @@ void CC STableMark ( void * item, void * data );
 bool CC STblMemberDefDump ( void *item, void *dumper );
 rc_t STblMemberDump ( const STblMember *self, struct SDumper *d );
 
+/*--------------------------------------------------------------------------
+ * SViewInstance
+ * A view with specified parameters
+*/
+typedef struct SViewInstance SViewInstance;
+struct SViewInstance
+{
+    const struct SView * dad;
+    Vector params; /* const KSymbol* */
+};
+
+void SViewInstanceWhack ( void *item, void *ignore );
+
+/*--------------------------------------------------------------------------
+ * SViewAliasMember
+ *  view alias member
+ */
+typedef struct SViewAliasMember SViewAliasMember;
+struct SViewAliasMember
+{
+    /* symbolic name */
+    struct KSymbol const *name;
+
+    /* parametrized view */
+    struct SViewInstance view;
+
+    /* contextual id */
+    VCtxId cid;
+};
+
+/* Whack
+ */
+void CC SViewAliasMemberWhack( void * self, void * ignore );
+
+/* Dump
+ */
+bool CC SViewAliasMemberDefDump ( void *item, void *dumper );
+rc_t SViewAliasMemberDump ( const STblMember *self, struct SDumper *d );
 
 /*--------------------------------------------------------------------------
  * SDBMember
@@ -1446,14 +1497,15 @@ struct SView
     /* owned KSymbols that are not in scope */
     Vector syms;
 
+    /* marking */
+    bool marked;
+
 #if NOT_NEEDED_YET
 
     /* source file & line */
     String src_file;
     uint32_t src_line;
 
-    /* marking */
-    bool marked;
 #endif
 };
 
@@ -1466,12 +1518,24 @@ rc_t SViewExtend ( struct KSymTable *tbl, SView *self, const SView *dad );
  */
 void SViewWhack ( void *self, void *ignore );
 
+/* Mark
+ */
+void SViewMark ( void *self, void *ignore );
+
+/* Dump
+ */
+bool CC SViewDefDump ( void *item, void *dumper );
+rc_t SViewDump ( const SView *self, struct SDumper *d );
+
 /* Cmp
  * Sort
  */
 int64_t SViewCmp ( const void *item, const void *n );
 int64_t SViewSort ( const void *item, const void *n );
 
+bool
+SViewIsA ( const SView * p_self, const SView * p_view );
+
 /* push/pop view scope
  *
  */
@@ -1493,7 +1557,7 @@ bool view_fwd_scan ( BSTNode *n, void *data );
 /* view_set_context
  * set context id on all view members
  */
-void view_set_context ( SView *self, uint32_t p_ctxId );
+void view_set_context ( SView *self );
 
 /* view_fix_forward_refs
  * fix forward references to newly resolved productions
@@ -1501,6 +1565,13 @@ void view_set_context ( SView *self, uint32_t p_ctxId );
 
 rc_t view_fix_forward_refs ( const SView *table );
 
+/* init-tbl-symtab
+ *  initializes "p_tbl"
+ *  places view in scope
+ *  must be balanced by KSymTableWhack
+ */
+rc_t init_view_symtab ( struct KSymTable * p_tbl, const VSchema * p_schema, const SView * p_view );
+
 /* SViewOverrides
 */
 typedef struct SViewOverrides SViewOverrides;
@@ -1515,18 +1586,6 @@ rc_t SViewOverridesMake ( Vector *parents, const SView *dad, const Vector *overr
 
 int64_t SViewOverridesCmp ( const void *item, const void *n );
 
-/* SViewInstance
- * A view with specified parameters
-*/
-typedef struct SViewInstance SViewInstance;
-struct SViewInstance
-{
-    const SView * dad;
-    Vector params; /* const KSymbol* */
-};
-
-void SViewInstanceWhack ( void *item, void *ignore );
-
 /* Find
  *  generic object find within view scope
  *
@@ -1562,8 +1621,14 @@ const void * SViewFind ( const SView *           self,
  */
 const struct KSymbol * SViewFindOverride ( const SView * self, const VCtxId * cid );
 
+/* Parse_v2
+ * Parse the text using bison-based front end and grammar version 2
+ * Log all errors
+ */
+bool VSchemaParse_v2 ( VSchema *self, const char *text, size_t bytes );
+
 #ifdef __cplusplus
 }
 #endif
 
-#endif /* _h_schema_priv_ */
+#endif /* _h_libs_schema_priv_ */
