@@ -135,16 +135,17 @@ rc_t SColumnDumpExpr ( SDumper *d, const SExpression *e )
 
     if ( ! compact )
         SDumperIncIndentLevel ( d );
-    rc = SDumperPrint ( d, compact ? "=%E" : "\n\t= %E\n", c -> left );
+
+    rc = SDumperPrint ( d, compact ? "=%E" : "\n\t= %E", c -> left );
     while ( rc == 0 )
     {
         if ( c -> right -> var != eCondExpr )
             break;
         c = ( const SBinExpr* ) c -> right;
-        rc = SDumperPrint ( d, compact ? "|%E" : "\n\t| %E\n", c -> left );
+        rc = SDumperPrint ( d, compact ? "|%E" : "\n\t| %E", c -> left );
     }
 
-    rc = SDumperPrint ( d, compact ? "|%E" : "\n\t| %E\n", c -> right );
+    rc = SDumperPrint ( d, compact ? "|%E;" : "\n\t| %E\n\t;\n", c -> right );
     if ( ! compact )
         SDumperDecIndentLevel ( d );
     return rc;
@@ -779,13 +780,13 @@ bool CC STableScanVirtuals ( void *item, void *data )
             else
             {
                 /* copy the original */
-                KSymbol *copy;
+                const KSymbol *copy;
+                KSymbol *prior;
                 rc_t rc = KSymbolCopy ( scope, & copy, orig );
                 if ( rc != 0 )
                     return true;
-
                 /* replace the parent virtual with an updatable copy */
-                VectorSwap ( & to -> by_parent, i, copy, & ignore );
+                VectorSwap ( & to -> by_parent, i, copy, (void**)& prior );
             }
         }
     }
@@ -963,7 +964,6 @@ rc_t STableImplicitPhysMember ( STable *self,
             m -> name = sym;
             sym -> u . obj = m;
             sym -> type = ePhysMember;
-
             /* add member to table */
             m -> cid . ctx = self -> id;
             rc = VectorAppend ( & self -> phys, & m -> cid . id, m );
@@ -1031,6 +1031,7 @@ rc_t STableImplicitColMember ( STable *self,
                     {
                         /* add column to table */
                         col -> cid . ctx = self -> id;
+                        col -> cid . ctx_type = eTable;
                         rc = VectorAppend ( & self -> col, & col -> cid . id, col );
                         if ( rc == 0 )
                         {
@@ -1038,7 +1039,7 @@ rc_t STableImplicitColMember ( STable *self,
                             SNameOverload *name;
 
                             /* create a column name with a single typed column */
-                            rc = SNameOverloadMake ( & name, csym, 0, 1 );
+                            rc = SNameOverloadMake ( & name, csym, eTable, 0, 1 );
                             if ( rc == 0 )
                             {
                                 /* being the only column, "col" may be simply
@@ -1359,6 +1360,32 @@ rc_t STableDump ( const STable *self, struct SDumper *d )
     return d -> rc;
 }
 
+/* IsA
+ * true if p_self and p_table are the same, or p_self is derived (directly or indirectly) from p_table
+ */
+bool
+STableIsA ( const STable * p_self, const STable * p_table )
+{
+    if ( p_self == p_table )
+    {
+        return true;
+    }
+    else
+    {
+        uint32_t i = VectorStart ( & p_self -> parents );
+        uint32_t count = VectorLength ( & p_self -> parents );
+        for ( count += i; i < count; ++ i )
+        {
+            const STable * dad = VectorGet ( & p_self -> parents, i );
+            if ( STableIsA ( dad, p_table ) )
+            {
+                return true;
+            }
+        }
+        return false;
+    }
+}
+
 #if _DEBUGGING
 static
 bool CC SProductionDumpVirtuals ( void *item, void *data )
@@ -2142,7 +2169,7 @@ rc_t column_declaration ( KSymTable *tbl, KTokenSource *src, KToken *t,
             SNameOverload *name = ( void* ) c -> name -> u . obj;
             if ( name == NULL )
             {
-                rc = SNameOverloadMake ( & name, c -> name, 0, 4 );
+                rc = SNameOverloadMake ( & name, c -> name, eTable, 0, 4 );
                 if ( rc == 0 )
                 {
                     name -> cid . ctx = -1;
@@ -2317,6 +2344,7 @@ bool CC table_fwd_scan ( BSTNode *n, void *data )
     {
         /* this symbol was introduced in THIS table */
         sym -> u . fwd . ctx = self -> id;
+        sym -> u . fwd . ctx_type = eTable;
 
         /* add it to the introduced virtual productions and make it virtual */
         pb -> rc = VectorAppend ( & self -> vprods, & sym -> u . fwd . id, sym );
@@ -2347,7 +2375,6 @@ rc_t table_body ( KSymTable *tbl, KTokenSource *src, KToken *t,
     rc_t rc = expect ( tbl, src, t, eLeftCurly, "{", true );
     if ( rc != 0 )
         return rc;
-
     while ( t -> id != eRightCurly )
     {
         rc = table_local_decl ( tbl, src, t, env, self, table );
@@ -2640,6 +2667,7 @@ void CC column_set_context ( void *item, void *data )
 {
     SColumn *self = item;
     self -> cid . ctx = * ( const uint32_t* ) data;
+    self -> cid . ctx_type = eTable;
 }
 
 static
@@ -2647,7 +2675,10 @@ void CC name_set_context ( void *item, void *data )
 {
     SNameOverload *self = item;
     if ( ( int32_t ) self -> cid . ctx < 0 )
+    {
         self -> cid . ctx = * ( const uint32_t* ) data;
+        self -> cid . ctx_type = eTable;
+    }
 }
 
 static
@@ -2655,6 +2686,7 @@ void CC physical_set_context ( void *item, void *data )
 {
     SPhysMember *self = item;
     self -> cid . ctx = * ( const uint32_t* ) data;
+    self -> cid . ctx_type = eTable;
 }
 
 static
@@ -2662,6 +2694,7 @@ void CC production_set_context ( void *item, void *data )
 {
     SProduction *self = item;
     self -> cid . ctx = * ( const uint32_t* ) data;
+    self -> cid . ctx_type = eTable;
 }
 
 static
@@ -2669,15 +2702,16 @@ void CC symbol_set_context ( void *item, void *data )
 {
     KSymbol *self = item;
     self -> u . fwd . ctx = * ( const uint32_t* ) data;
+    self -> u . fwd . ctx_type = eTable;
 }
 
-void CC table_set_context ( STable *self, uint32_t p_ctxId )
+void CC table_set_context ( STable *self )
 {
-    VectorForEach ( & self -> col, false, column_set_context, & p_ctxId );
-    VectorForEach ( & self -> cname, false, name_set_context, & p_ctxId );
-    VectorForEach ( & self -> phys, false, physical_set_context, & p_ctxId );
-    VectorForEach ( & self -> prod, false, production_set_context, & p_ctxId );
-    VectorForEach ( & self -> vprods, false, symbol_set_context, & p_ctxId );
+    VectorForEach ( & self -> col, false, column_set_context, & self -> id );
+    VectorForEach ( & self -> cname, false, name_set_context, & self -> id );
+    VectorForEach ( & self -> phys, false, physical_set_context, & self -> id );
+    VectorForEach ( & self -> prod, false, production_set_context, & self -> id );
+    VectorForEach ( & self -> vprods, false, symbol_set_context, & self -> id );
 }
 
 #if NO_UPDATE_TBL_REF || 0
@@ -2870,7 +2904,7 @@ rc_t table_declaration ( KSymTable *tbl, KTokenSource *src, KToken *t,
         SNameOverload *name = ( void* ) table -> name -> u . obj;
         if ( name == NULL )
         {
-            rc = SNameOverloadMake ( & name, table -> name, 0, 4 );
+            rc = SNameOverloadMake ( & name, table -> name, 0, 0, 4 );
             if ( rc == 0 )
             {
                 rc = VectorAppend ( & self -> tname, & name -> cid . id, name );
@@ -2887,13 +2921,12 @@ rc_t table_declaration ( KSymTable *tbl, KTokenSource *src, KToken *t,
                 uint32_t idx;
 
                 /* set the table context id on all members */
-                table_set_context ( table, table -> id );
+                table_set_context ( table );
 
                 /* add to named table overrides */
                 rc = VectorInsertUnique ( & name -> items, table, & idx, STableSort );
                 if ( rc == 0 )
                     return 0;
-
                 if ( GetRCState ( rc ) == rcExists )
                 {
                     const STable *newer;
@@ -2903,7 +2936,6 @@ rc_t table_declaration ( KSymTable *tbl, KTokenSource *src, KToken *t,
                     {
                         /* put the new one in place of the existing */
                         VectorSwap ( & name -> items, idx, table, & ignore );
-
                         /* tell everyone to use new table */
                         return schema_update_tbl_ref ( self, exist, table );
                     }
@@ -2917,7 +2949,6 @@ rc_t table_declaration ( KSymTable *tbl, KTokenSource *src, KToken *t,
     {
         rc = 0;
     }
-
     STableWhack ( table, NULL );
 
     return rc;
