@@ -49,7 +49,12 @@
 #include <klib/printf.h>
 #include <klib/out.h>
 #include <klib/rc.h>
+#include <klib/text.h>
+
+#include <vdb/schema-priv.h> /* KSymbolName */
 #include <vdb/vdb-priv.h>
+
+#include <kfg/properties.h>
 #include <sysalloc.h>
 
 #include <stdlib.h>
@@ -353,7 +358,6 @@ rc_t CC KMDataNodeFillSchema ( void *data, KTokenText *tt, size_t save )
         tt -> str . len = string_len ( pb -> buff, save + num_read );
         pb -> pos += num_read;
     }
-
     return rc;
 }
 
@@ -374,7 +378,7 @@ void CC SNameOverloadWhack ( void *item, void *ignore )
 /* Make
  */
 rc_t SNameOverloadMake ( SNameOverload **np,
-    const KSymbol *sym, uint32_t start, uint32_t len )
+    const KSymbol *sym, uint32_t ctx_type, uint32_t start, uint32_t len )
 {
     SNameOverload *name = malloc ( sizeof * name );
     if ( name == NULL )
@@ -384,6 +388,7 @@ rc_t SNameOverloadMake ( SNameOverload **np,
     ( ( KSymbol* ) sym ) -> u . obj = name;
     VectorInit ( & name -> items, start, len );
     name -> cid . ctx = 0;
+    name -> cid . ctx_type = ctx_type; /* 0 for top-level objects (table, db, function) */
 
     * np = name;
     return 0;
@@ -399,7 +404,7 @@ rc_t SNameOverloadCopy ( BSTree *scope,
     if ( rc == 0 )
     {
         SNameOverload *copy;
-        rc = SNameOverloadMake ( & copy, sym, 0, 0 );
+        rc = SNameOverloadMake ( & copy, sym, orig -> cid . ctx_type, 0, 0 );
         if ( rc == 0 )
         {
             /* copy contents */
@@ -777,7 +782,7 @@ LIB_EXPORT rc_t CC VSchemaVAddIncludePath ( VSchema *self, const char *path, va_
         path=".";
 
     if (strchr(path, '%') == NULL)
-        temp = strdup(path);
+        temp = string_dup_measure(path, NULL);
     else {
         KDataBuffer buffer;
 
@@ -786,7 +791,7 @@ LIB_EXPORT rc_t CC VSchemaVAddIncludePath ( VSchema *self, const char *path, va_
         if (rc)
             return rc;
 
-        temp = strdup(buffer.base);
+        temp = string_dup_measure(buffer.base, NULL);
         KDataBufferWhack(&buffer);
     }
     if (temp == NULL)
@@ -855,7 +860,7 @@ LIB_EXPORT rc_t CC VSchemaAddIncludePaths(VSchema *self, size_t length, const ch
 }
 
 
-/* ParseText
+/* ParseText_v1
  *  parse schema text
  *  add productions to existing schema
  *
@@ -865,8 +870,8 @@ LIB_EXPORT rc_t CC VSchemaAddIncludePaths(VSchema *self, size_t length, const ch
  *  "text" [ IN ] and "bytes" [ IN ] - input buffer of text
  */
 static
-rc_t CC VSchemaParseTextInt ( VSchema *self,
-    const char *name, const char *text, size_t bytes )
+rc_t
+VSchemaParseTextInt_v1 ( VSchema *self, const char *name, const char *text, size_t bytes )
 {
     KTokenText tt;
     KTokenSource src;
@@ -874,24 +879,76 @@ rc_t CC VSchemaParseTextInt ( VSchema *self,
     rc_t rc;
 
     if ( name == NULL || name [ 0 ] == 0 )
+    {
         CONST_STRING ( & path, "<unnamed>" );
+    }
     else
+    {
         StringInitCString ( & path, name );
+    }
 
     StringInit ( & str, text, bytes, string_len ( text, bytes ) );
     KTokenTextInit ( & tt, & str, & path );
     KTokenSourceInit ( & src, & tt );
 
     rc = schema ( & src, self );
-
     if (rc == 0)
-        PARSE_DEBUG( ("Parsed schema from %s\n", name) );
+    {
+        PARSE_DEBUG( ("Parsed schema v1 from %s\n", name) );
+    }
     else
-        PARSE_DEBUG( ("Failed to parse schema from %s\n", name) );
+    {
+        PARSE_DEBUG( ("Failed to parse v1 schema from %s\n", name) );
+    }
 
     return rc;
 }
 
+static
+rc_t
+VSchemaParseTextInt_v2 ( VSchema *self, const char *name, const char *text, size_t bytes )
+{
+    //printf("VSchemaParseTextInt_v2:\n%.*s\n", (int)bytes, text);
+    if ( VSchemaParse_v2 ( self, text, bytes ) )
+    {
+        PARSE_DEBUG( ("Parsed schema v2 from %s\n", name) );
+        return 0;
+    }
+
+    PARSE_DEBUG( ("Failed to parse v2 schema from %s\n", name) );
+    return RC ( rcVDB, rcSchema, rcOpening, rcSchema, rcFailed );
+}
+
+static
+rc_t
+VSchemaParseTextInt ( VSchema *self, const char *name, const char *text, size_t bytes )
+{
+    KConfig * kfg;
+    rc_t rc = KConfigMake ( & kfg, NULL );
+    if ( rc == 0 )
+    {
+        uint8_t version;
+        rc = KConfigGetSchemaParserVersion( kfg , & version );
+        if ( rc == 0 )
+        {
+            switch (version)
+            {
+            case 1:
+                rc = VSchemaParseTextInt_v1 ( self, name, text, bytes );
+                break;
+            case 2:
+                rc = VSchemaParseTextInt_v2 ( self, name, text, bytes );
+                break;
+            default:
+                rc = RC ( rcVDB, rcSchema, rcParsing, rcFileFormat, rcUnsupported );
+                break;
+            }
+        }
+    }
+    KConfigRelease ( kfg );
+    return rc;
+}
+
 LIB_EXPORT rc_t CC VSchemaParseText ( VSchema *self, const char *name,
     const char *text, size_t bytes )
 {
@@ -906,7 +963,9 @@ LIB_EXPORT rc_t CC VSchemaParseText ( VSchema *self, const char *name,
     else if ( text == NULL )
         rc = RC ( rcVDB, rcSchema, rcParsing, rcParam, rcNull );
     else
-        rc = VSchemaParseTextInt ( self, name, text, bytes );
+    {
+        rc = VSchemaParseTextInt ( self, name, text, bytes);
+    }
 
     return rc;
 }
@@ -924,16 +983,49 @@ LIB_EXPORT rc_t CC VSchemaParseText ( VSchema *self, const char *name,
 rc_t VSchemaParseTextCallback ( VSchema *self, const char *name,
     rc_t ( CC * fill ) ( void *self, KTokenText *tt, size_t save ), void *data )
 {
-    KTokenText tt;
-    KTokenSource src;
+    KConfig * kfg;
+    rc_t rc = KConfigMake ( & kfg, NULL );
+    if ( rc == 0 )
+    {
+        uint8_t version;
 
-    KTokenTextInitCString ( & tt, "", name );
-    tt . read = fill;
-    tt . data = data;
+        rc = KConfigGetSchemaParserVersion( kfg , & version );
+        if ( rc == 0 )
+        {
+            switch (version)
+            {
+            case 1:
+                {
+                    KTokenText tt;
+                    KTokenSource src;
 
-    KTokenSourceInit ( & src, & tt );
+                    KTokenTextInitCString ( & tt, "", name );
+                    tt . read = fill;
+                    tt . data = data;
+
+                    KTokenSourceInit ( & src, & tt );
+                    /*NB: this invokes v1 parser, even though the parent schema may have been
+                        processed by v2 parser. The reason is the possibility of v0 constructs
+                        coming from older objects */
+                    rc = schema ( & src, self );
+                }
+                break;
+            case 2:
+                {
+                    KTokenText tt;
+                    rc = fill ( data, & tt, 0 );
+                    rc = VSchemaParseTextInt_v2 ( self, name, tt.str.addr, tt.str.size );
+                }
+                break;
+            default:
+                rc = RC ( rcVDB, rcSchema, rcParsing, rcFileFormat, rcUnsupported );
+                break;
+            }
+        }
+    }
+    KConfigRelease ( kfg );
+    return rc;
 
-    return schema ( & src, self );
 }
 
 
@@ -1970,3 +2062,110 @@ LIB_EXPORT rc_t CC VSchemaRuntimeTableAddUnicodeColumn ( VSchemaRuntimeTable *se
 
     return rc;
 }
+
+/*******************************************************************************
+ Private functions
+ to access to internals of VSchema to allow them to be used in other projects.
+*/
+
+rc_t SDatabaseGetDad(const SDatabase * self, const struct SDatabase ** dad) {
+    assert(self && dad); *dad = self->dad; return 0;
+}
+
+rc_t STableGetParents(const STable * self, const struct Vector ** parents) {
+    assert(self && parents); *parents = &self->parents; return 0;
+}
+
+rc_t SViewGetParents(const SView * self, const struct Vector ** parents) {
+    assert(self && parents); *parents = &self->parents; return 0;
+}
+
+rc_t VSchemaGetDb(const VSchema * self, const Vector ** db) {
+    assert(self && db); *db = &self->db; return 0;
+}
+
+rc_t VSchemaGetTbl(const VSchema * self, const Vector ** tbl) {
+    assert(self && tbl); *tbl = &self->tbl; return 0;
+}
+
+rc_t VSchemaGetView(const VSchema * self, const Vector ** view) {
+    assert(self && view); *view = &self->view; return 0;
+}
+
+rc_t KSymbolNameWhack(KSymbolName * self) {
+    if (self != NULL) {
+        KSymbolNameElm *name = self->name;
+        while (name != NULL) {
+            KSymbolNameElm * next = name->next;
+            memset(name, 0, sizeof *name);
+            free(name);
+            name = next;
+        }
+
+        memset(self, 0, sizeof *self);
+        free(self);
+    }
+
+    return 0;
+}
+
+static KSymbolName * KSymbolMakeKSymbolName(const KSymbol * self,
+    uint32_t version)
+{
+    KSymbolName * out = NULL;
+    KSymbolNameElm * head = NULL;
+
+    assert(self);
+
+    for (; self; self = self->dad) {
+        KSymbolNameElm * prev = NULL;
+        const String * n = &self->name;
+        assert(n);
+        prev = calloc(1, sizeof *prev);
+        if (prev == NULL)
+            return NULL;
+
+        prev->name = n;
+        prev->next = head;
+        head = prev;
+    }
+
+    out = calloc(1, sizeof *out);
+    if (out == NULL)
+        return NULL;
+
+    out->name = head;
+    out->version = version;
+    return out;
+}
+
+rc_t SDatabaseMakeKSymbolName(const SDatabase * self,
+    KSymbolName ** out)
+{
+    assert(self && out);
+    *out = KSymbolMakeKSymbolName(self->name, self->version);
+    if (*out == NULL)
+        return RC(rcVDB, rcSchema, rcListing, rcMemory, rcExhausted);
+    else
+        return 0;
+}
+
+rc_t STableMakeKSymbolName(const STable * self, KSymbolName ** out) {
+    assert(self && out);
+    *out = KSymbolMakeKSymbolName(self->name, self->version);
+    if (*out == NULL)
+        return RC(rcVDB, rcSchema, rcListing, rcMemory, rcExhausted);
+    else
+        return 0;
+}
+
+rc_t SViewMakeKSymbolName(const SView * self, KSymbolName ** out) {
+    assert(self && out);
+    *out = KSymbolMakeKSymbolName(self->name, self->version);
+    if (*out == NULL)
+        return RC(rcVDB, rcSchema, rcListing, rcMemory, rcExhausted);
+    else
+        return 0;
+}
+
+/******************************************************************************/
