@@ -35,11 +35,11 @@
 #include "cursor-priv.h"
 #include "prod-priv.h"
 #include "blob-priv.h"
-#include "page-map.h"
 
 #include <vdb/manager.h>
 #include <vdb/cursor.h>
 #include <kdb/column.h>
+#include <kdb/page-map.h>
 #include <klib/log.h>
 #include <klib/rc.h>
 #include <bitstr.h>
