@@ -24,5 +24,5 @@
 
 #include <klib/strings.h> /* SDL_CGI */
 
-#define RESOLVER_CGI "https://trace.ncbi.nlm.nih.gov/Traces/names/names.fcgi"
-#define RESOLVER_CGI_HTTP RESOLVER_CGI
+//#define RESOLVER_CGI "https://trace.ncbi.nlm.nih.gov/Traces/names/names.fcgi"
+//#define RESOLVER_CGI_HTTP RESOLVER_CGI
