@@ -203,8 +203,8 @@ rc_t CC sprintf_func ( void *obj,
     {
         size_t arg_size;
         bool check_index;
-        uint64_t row_len, start_idx, select_len;
-        uint32_t ext_start_index, ext_stop_index;
+        uint64_t row_len, start_idx = 0, select_len = 0;
+        uint32_t ext_start_index = 0, ext_stop_index = 0;
 
         row_len = 0;
 
@@ -1183,7 +1183,7 @@ VTRANSFACT_IMPL ( vdb_sprintf, 1, 0, 0 ) ( const void *self, const VXfactInfo *i
     VFuncDesc *rslt, const VFactoryParams *cp, const VFunctionParams *dp )
 {
     rc_t rc;
-    Sprintf *obj;
+    Sprintf *obj = NULL;
 
     /* const format string */
     VAList vargs;
