@@ -44,6 +44,8 @@ using namespace std;
 
 TEST_SUITE(KdbTestSuite);
 
+static const string ScratchDir = "./data/";
+
 #define KDB_MANAGER_MAKE(m_mgr, m_wd) KDBManagerMakeUpdate((KDBManager **)m_mgr, (struct KDirectory *)m_wd)
 #include "remote_open_test.cpp"
 
@@ -81,9 +83,9 @@ public:
 
 FIXTURE_TEST_CASE ( MissingRows, WKDB_Fixture )
 {   // VDB-177
-    KDirectoryRemove(m_wd, true, GetName());
+    KDirectoryRemove(m_wd, true, (ScratchDir + GetName()).c_str() );
     KDatabase* db;
-    REQUIRE_RC(KDBManagerCreateDB(m_mgr, &db, kcmCreate, GetName()));
+    REQUIRE_RC(KDBManagerCreateDB(m_mgr, &db, kcmCreate, (ScratchDir + GetName()).c_str() ));
 
     KIndex *idx;
     REQUIRE_RC(KDatabaseCreateIndex(db, &idx, kitText, kcmCreate, "index"));
@@ -107,12 +109,11 @@ FIXTURE_TEST_CASE ( MissingRows, WKDB_Fixture )
     KIndexRelease(idx);
 
     REQUIRE_RC(KDatabaseRelease(db));
-    KDirectoryRemove(m_wd, true, GetName());
 }
 
-FIXTURE_TEST_CASE ( ColumnMetadataWKDB_Fixture, WKDB_Fixture )
+FIXTURE_TEST_CASE ( ColumnMetadata, WKDB_Fixture )
 {
-    KDirectoryRemove(m_wd, true, GetName());
+    KDirectoryRemove(m_wd, true, (ScratchDir + GetName()).c_str());
 
     const char* TableName = "tbl";
     const char* ColumnName = "col";
@@ -121,10 +122,10 @@ FIXTURE_TEST_CASE ( ColumnMetadataWKDB_Fixture, WKDB_Fixture )
 
     {
         KDatabase* db;
-        REQUIRE_RC(KDBManagerCreateDB(m_mgr, &db, kcmCreate, GetName()));
+        REQUIRE_RC(KDBManagerCreateDB(m_mgr, &db, kcmCreate, (ScratchDir + GetName()).c_str()));
 
         KTable* tbl;
-        REQUIRE_RC ( KDBManagerCreateTable ( m_mgr, & tbl, kcmInit + kcmMD5, TableName ) );
+        REQUIRE_RC ( KDBManagerCreateTable ( m_mgr, & tbl, kcmInit + kcmMD5, (ScratchDir + TableName).c_str() ) );
 
         KColumn* col;
         REQUIRE_RC ( KTableCreateColumn ( tbl, & col, kcmInit, kcmMD5, 0, ColumnName ) );
@@ -150,10 +151,10 @@ FIXTURE_TEST_CASE ( ColumnMetadataWKDB_Fixture, WKDB_Fixture )
     }
     {   // reopen, verify
         KDatabase* db;
-        REQUIRE_RC ( KDBManagerOpenDBUpdate ( m_mgr, &db, GetName() ) );
+        REQUIRE_RC ( KDBManagerOpenDBUpdate ( m_mgr, &db, (ScratchDir + GetName()).c_str() ) );
 
         const KTable* tbl;
-        REQUIRE_RC ( KDBManagerOpenTableRead ( m_mgr, & tbl, TableName ) );
+        REQUIRE_RC ( KDBManagerOpenTableRead ( m_mgr, & tbl, (ScratchDir + TableName).c_str() ) );
 
         const KColumn* col;
         REQUIRE_RC ( KTableOpenColumnRead ( tbl, & col, ColumnName ) );
@@ -164,70 +165,8 @@ FIXTURE_TEST_CASE ( ColumnMetadataWKDB_Fixture, WKDB_Fixture )
         REQUIRE_RC ( KTableRelease ( tbl ) );
         REQUIRE_RC ( KDatabaseRelease ( db ) );
     }
-
-    KDirectoryRemove(m_wd, true, TableName);
-    KDirectoryRemove(m_wd, true, GetName());
 }
 
-// KColumnBlob
-// see same tests on the read side, kdbtest.cpp
-
-class ColumnBlobReadFixture
-{
-public:
-    ColumnBlobReadFixture()
-    :   m_num_read ( 0 ),
-        m_remaining ( 0 )
-    {
-        KDBManager* mgr;
-        THROW_ON_RC ( KDBManagerMakeUpdate( & mgr, NULL ) );
-
-        const KTable* tbl;
-        THROW_ON_RC ( KDBManagerOpenTableRead ( mgr, & tbl, "SRR000123" ) );
-
-        const KColumn* col;
-        THROW_ON_RC ( KTableOpenColumnRead ( tbl, & col, "X" ) );
-
-        THROW_ON_RC ( KColumnOpenBlobRead ( col, & m_blob, 1 ) );
-
-        THROW_ON_RC ( KColumnRelease ( col ) );
-        THROW_ON_RC ( KTableRelease ( tbl ) );
-        THROW_ON_RC ( KDBManagerRelease ( mgr ) );
-    }
-    ~ColumnBlobReadFixture()
-    {
-        KColumnBlobRelease ( m_blob );
-    }
-
-    const KColumnBlob*  m_blob;
-    size_t m_num_read;
-    size_t m_remaining;
-};
-
-FIXTURE_TEST_CASE ( ColumnBlobRead_basic, ColumnBlobReadFixture )
-{
-    const size_t BlobSize = 1882;
-    const size_t BufSize = 2024;
-    char buffer [ BufSize ];
-    REQUIRE_RC ( KColumnBlobRead ( m_blob, 0, buffer, BufSize, & m_num_read, & m_remaining ) );
-    REQUIRE_EQ ( BlobSize, m_num_read );
-    REQUIRE_EQ ( (size_t)0, m_remaining );
-}
-
-FIXTURE_TEST_CASE ( ColumnBlobRead_insufficient_buffer, ColumnBlobReadFixture )
-{
-    const size_t BlobSize = 1882;
-    const size_t BufSize = 1024;
-    char buffer [ BufSize ];
-    // first read incomplete
-    REQUIRE_RC ( KColumnBlobRead ( m_blob, 0, buffer, BufSize, & m_num_read, & m_remaining ) );
-    REQUIRE_EQ ( BufSize, m_num_read );
-    REQUIRE_EQ ( BlobSize - BufSize, m_remaining );
-    // the rest comes in on the second read
-    REQUIRE_RC ( KColumnBlobRead ( m_blob, BufSize, buffer, BufSize, & m_num_read, & m_remaining ) );
-    REQUIRE_EQ ( BlobSize - BufSize, m_num_read );
-    REQUIRE_EQ ( (size_t)0, m_remaining );
-}
 
 //////////////////////////////////////////// Main
 extern "C"
