@@ -86,7 +86,7 @@ protected:
     public:
         // danger - this should be an extern "C" function
         // with CC calling convention on Windows
-        static rc_t KLock_ThreadFn ( const KThread *thread, void *data )
+        static rc_t KLock_ThreadFn ( const KThread *thread, void *data ) noexcept
         {
             KLockFixture* self = (KLockFixture*)data;
             
@@ -179,7 +179,7 @@ protected:
     public:
         // danger - this should be an extern "C" function
         // with CC calling convention on Windows
-        static rc_t KLock_Timed_ThreadFn ( const KThread *thread, void *data )
+        static rc_t KLock_Timed_ThreadFn ( const KThread *thread, void *data ) noexcept
         {
             KTimedLockFixture* self = (KTimedLockFixture*)data;
             
@@ -333,7 +333,7 @@ protected:
             atomic32_set( & self->threadWaiting, false );
             return 0;
         }
-        static rc_t KRWLock_Writer_ThreadFn ( const KThread *thread, void *data )
+        static rc_t KRWLock_Writer_ThreadFn ( const KThread *thread, void *data ) noexcept
         {
             KRWLockFixture* self = (KRWLockFixture*)data;
             atomic32_set( & self->threadWaiting, true );
@@ -360,7 +360,7 @@ protected:
             atomic32_set( & self->threadWaiting, false );
             return 0;
         }
-        static rc_t KRWLock_WriterTimed_ThreadFn ( const KThread *thread, void *data )
+        static rc_t KRWLock_WriterTimed_ThreadFn ( const KThread *thread, void *data ) noexcept
         {
             KRWLockFixture* self = (KRWLockFixture*)data;
             atomic32_set( & self->threadWaiting, true );
@@ -581,7 +581,7 @@ protected:
     public:
         // danger - this should be an extern "C" function
         // with CC calling convention on Windows
-        static rc_t KCondition_ThreadFn ( const KThread *thread, void *data )
+        static rc_t KCondition_ThreadFn ( const KThread *thread, void *data ) noexcept
         {
             KConditionFixture* self = (KConditionFixture*)data;
 
@@ -665,7 +665,8 @@ TEST_CASE(KQueueSimpleTest) {
     KQueue * queue = NULL;
     REQUIRE_RC(KQueueMake(&queue, 2));
 
-    timeout_t tm = { 0 };
+    timeout_t tm;
+    memset( & tm, 0, sizeof( tm ) );
     void *item = NULL;
     {   // pushed 2 - popped 2 = ok
         for (uint64_t i = 1; i < 3; ++i) {
@@ -769,7 +770,7 @@ protected:
     public:
         // danger - this should be an extern "C" function
         // with CC calling convention on Windows
-        static rc_t KQueue_ThreadFn ( const KThread *thread, void *data )
+        static rc_t KQueue_ThreadFn ( const KThread *thread, void *data ) noexcept
         {
             ThreadData* td = (ThreadData*)data;
             rc_t rc = 0;
@@ -777,7 +778,8 @@ protected:
 
             for (int i = 0; i < numOps; ++i)
             {
-                timeout_t tm = { 0 };
+                timeout_t tm;
+                memset( & tm, 0, sizeof( tm ) );
                 timeout_t* tm_p = &tm;
                 void * item;
                 if (tm_p != NULL)
