@@ -25,9 +25,22 @@
 */
 
 /**
-* Unit tests for database declarations in schema, this file is #included into a bigger test suite
+* Unit tests for database declarations in schema
 */
 
+#include "AST_Fixture.hpp"
+
+#include <ktst/unit_test.hpp>
+
+#include <klib/symbol.h>
+
+//#include "../../libs/vdb/schema-expr.h"
+
+using namespace std;
+using namespace ncbi::NK;
+
+TEST_SUITE ( SchemaDbTestSuite );
+
 class DbAccess // encapsulates access to an STable in a VSchema
 {
 public:
@@ -54,6 +67,12 @@ public:
         return static_cast < const STblMember * > ( VectorGet ( & m_self -> tbl, p_idx ) );
     }
 
+    uint32_t AliasMemberCount () const { return VectorLength ( & m_self -> aliases ); }
+    const SViewAliasMember * GetAliasMember ( uint32_t p_idx ) const
+    {
+        return static_cast < const SViewAliasMember * > ( VectorGet ( & m_self -> aliases, p_idx ) );
+    }
+
     uint32_t OverloadCount () const
     {
         const SNameOverload * ovl = static_cast < const SNameOverload * > ( m_self -> name -> u . obj );
@@ -115,7 +134,7 @@ FIXTURE_TEST_CASE(DB_Parent, AST_Db_Fixture)
     REQUIRE_EQ ( 0u, db . Parent () -> id );
 }
 
-FIXTURE_TEST_CASE(DB_ParentNotADatabase, AST_Table_Fixture)
+FIXTURE_TEST_CASE(DB_ParentNotADatabase, AST_Db_Fixture)
 {
     VerifyErrorMessage ( "table p#1 {}; database d#1 = p#1 {};", "Not a database: 'p'" );
 }
@@ -147,7 +166,7 @@ FIXTURE_TEST_CASE(DB_DbMember, AST_Db_Fixture)
     REQUIRE_EQ ( (uint32_t)eDBMember, sym -> type );
 }
 
-FIXTURE_TEST_CASE(DB_DbMemberDeclaredTwice, AST_Table_Fixture)
+FIXTURE_TEST_CASE(DB_DbMemberDeclaredTwice, AST_Db_Fixture)
 {
     VerifyErrorMessage ( "database p#1 {}; database d#1 { database p m_p; database p m_p; };",
                          "Member already exists: 'm_p'",
@@ -156,17 +175,17 @@ FIXTURE_TEST_CASE(DB_DbMemberDeclaredTwice, AST_Table_Fixture)
 
 //TODO: table member declared twice
 
-FIXTURE_TEST_CASE(DB_ItselfAsMember, AST_Table_Fixture)
+FIXTURE_TEST_CASE(DB_ItselfAsMember, AST_Db_Fixture)
 {
     VerifyErrorMessage ( "database d#1 { database d m_p; };", "Database declared but not defined: 'd'" );
 }
 
-FIXTURE_TEST_CASE(DB_DbMemberNotADatabase, AST_Table_Fixture)
+FIXTURE_TEST_CASE(DB_DbMemberNotADatabase, AST_Db_Fixture)
 {
     VerifyErrorMessage ( "table p#1 {}; database d#1 { database p m_p; };", "Not a database: 'p'" );
 }
 
-FIXTURE_TEST_CASE(DB_DbMemberVersionDoesNotExist, AST_Table_Fixture)
+FIXTURE_TEST_CASE(DB_DbMemberVersionDoesNotExist, AST_Db_Fixture)
 {
     VerifyErrorMessage ( "database p#1 {}; database d#1 { database p#2 m_p; };",
                          "Requested version does not exist: 'p#2'" );
@@ -204,3 +223,131 @@ FIXTURE_TEST_CASE(DB_TableMemberTemplate, AST_Db_Fixture)
     const STblMember * m = db . GetTableMember ( 0 );
     REQUIRE ( m -> tmpl );
 }
+
+FIXTURE_TEST_CASE(DB_ViewAliasMember_NotAView, AST_Db_Fixture)
+{
+    VerifyErrorMessage ( "version 2; table t#1 {}; view v#1 < t t > {}; database d#1 { table t T; alias t<T> vv; };",
+                         "Not a view: 't'" );
+}
+FIXTURE_TEST_CASE(DB_ViewAliasMember_AlreadyExists, AST_Db_Fixture)
+{
+    VerifyErrorMessage ( "version 2; table t#1 {}; view v#1 <t t > {}; database d#1 { table t T; alias v<T> T; };",
+                         "Member already exists: 'T'" );
+}
+FIXTURE_TEST_CASE(DB_ViewAliasMember_UnknownParameter, AST_Db_Fixture)
+{
+    VerifyErrorMessage ( "version 2; table t#1 {}; view v#1 <t t > {}; database d#1 { table t T; alias v<zz> vv; };",
+                         "Undeclared identifier: 'zz'" );
+}
+FIXTURE_TEST_CASE(DB_ViewAliasMember_WrongParameter, AST_Db_Fixture)
+{
+    VerifyErrorMessage ( "version 2; table t#1 {}; view v#1 <t t > {}; database d#1 { table t T; alias v<t> vv; };",
+                         "Not a table/view member: 't'" );
+}
+FIXTURE_TEST_CASE(DB_ViewAliasMember_WrongParameterCount, AST_Db_Fixture)
+{
+    VerifyErrorMessage ( "version 2; table t#1 {}; view v#1 <t t > {}; database d#1 { table t T; alias v<T,T> vv; };",
+                         "Incorrect number of view parameters: 'v'" );
+}
+FIXTURE_TEST_CASE(DB_ViewAliasMember_TableParamTypeMismatch, AST_Db_Fixture)
+{
+    VerifyErrorMessage (
+        "version 2;"
+        "table t1#1 {}; table t2#1 {}; view v#1 < t1 t > {}; "
+        "database d#1 { table t2 T; alias v<T> vv; };",
+        "View parameter type mismatch: 'T'" );
+}
+FIXTURE_TEST_CASE(DB_ViewAliasMember_ViewParamTypeMismatch, AST_Db_Fixture)
+{
+    VerifyErrorMessage (
+        "version 2;"
+        "table t#1 {}; view v1#1 < t t > {}; view v2#1 < t t > {}; view u#1<v1 v>{};"
+        "database d#1 { table t T; alias v2<T> vv; alias u< vv > uu; };",
+        "View parameter type mismatch: 'vv'" );
+}
+
+FIXTURE_TEST_CASE(DB_ViewAliasMember, AST_Db_Fixture)
+{
+    DbAccess db = ParseDatabase ( "version 2; table t#1 {}; view v#1 < t t > {}; database d#1 { table t T; alias v<T> vv; };", "d", 0 );
+    REQUIRE_EQ ( 1u, db . AliasMemberCount () );
+    const SViewAliasMember * m = db . GetAliasMember ( 0 );
+    REQUIRE ( m );
+    // verify the internals
+    REQUIRE_EQ( string("vv"), ToCppString ( m -> name -> name ) );
+    const struct SViewInstance & inst = m -> view;
+    REQUIRE_EQ( string("v"), ToCppString ( inst . dad -> name -> name ) );
+
+    VdbVector<KSymbol> params ( inst . params );
+    REQUIRE_EQ( 1u, params.Count() );
+    const KSymbol* p ( params.Get( 0 ) );
+    REQUIRE_NOT_NULL( p );
+    REQUIRE_EQ( string("T"), ToCppString ( p -> name ) );
+
+    REQUIRE_EQ( 0u, m -> cid . ctx ); // currently not used for view aliases
+    REQUIRE_EQ( 0u, m -> cid . id ); // index into db.aliases
+}
+
+FIXTURE_TEST_CASE(DB_ViewOnAliasMemberOnAnotherViewAliasMember, AST_Db_Fixture)
+{
+    DbAccess db = ParseDatabase (
+        "version 2;"
+        "table t#1 {}; view v1#1 < t t > {}; view v2#1 < v1 v > {};"
+        "database d#1 { table t T; alias v1<T> vv1; alias v2< vv1 > vv2; };",
+        "d", 0 );
+    REQUIRE_EQ ( 2u, db . AliasMemberCount () );
+    const SViewAliasMember * m = db . GetAliasMember ( 1 );
+    REQUIRE ( m );
+    // verify the internals
+    REQUIRE_EQ( string("vv2"), ToCppString ( m -> name -> name ) );
+    const struct SViewInstance & inst = m -> view;
+    REQUIRE_EQ( string("v2"), ToCppString ( inst . dad -> name -> name ) );
+
+    VdbVector<KSymbol> params ( inst . params );
+    REQUIRE_EQ( 1u, params.Count() );
+    const KSymbol* p ( params.Get( 0 ) );
+    REQUIRE_NOT_NULL( p );
+    REQUIRE_EQ( string("vv1"), ToCppString ( p -> name ) );
+
+    REQUIRE_EQ( 0u, m -> cid . ctx );
+    REQUIRE_EQ( 1u, m -> cid . id );
+}
+
+//TODO: DB_ViewOnAliasMemberOnAnotherViewAliasMember
+//TODO: DB_ViewAliasMemberOnTableFromParentDatabase
+
+//TODO: SViewAliasMemberMark
+//TODO: SViewAliasMemberDefDump
+//TODO: SViewAliasMemberDump
+
+//////////////////////////////////////////// Main
+#include <kapp/args.h>
+#include <kfg/config.h>
+#include <klib/out.h>
+
+extern "C"
+{
+
+ver_t CC KAppVersion ( void )
+{
+    return 0x1000000;
+}
+
+const char UsageDefaultName[] = "wb-test-schema-db";
+
+rc_t CC UsageSummary (const char * progname)
+{
+    return KOutMsg ( "Usage:\n" "\t%s [options] -o path\n\n", progname );
+}
+
+rc_t CC Usage( const Args* args )
+{
+    return 0;
+}
+
+rc_t CC KMain ( int argc, char *argv [] )
+{
+    return SchemaDbTestSuite(argc, argv);
+}
+
+}
+
