@@ -35,9 +35,11 @@
 #include <vdb/vdb-priv.h>
 
 #include <../libs/vdb/schema-priv.h>
+#include <../libs/vdb/schema-parse.h>
 #include <../libs/vdb/table-priv.h>
 #include <../libs/vdb/cursor-priv.h>
 #include <../libs/vdb/prod-priv.h>
+#include <../libs/vdb/column-priv.h>
 
 #include <ktst/unit_test.hpp>
 
@@ -48,7 +50,41 @@ using namespace std;
 static rc_t argsHandler ( int argc, char * argv [] );
 TEST_SUITE_WITH_ARGS_HANDLER ( VdbTableCursorTestSuite_Read, argsHandler );
 
-const string ScratchDir = "./db/";
+const char * Accession = "SRR600096";
+
+// VTable
+
+TEST_CASE( VTable_ListReadableColumns )
+{
+    KNamelist * columns; // VColumnRef
+    {
+        const VTable * tbl;
+        {
+            const VDatabase * db;
+            {
+                const VDBManager * mgr;
+                REQUIRE_RC ( VDBManagerMakeRead ( & mgr, NULL ) );
+                REQUIRE_RC ( VDBManagerOpenDBRead ( mgr, & db, NULL, "%s", Accession ) );
+                REQUIRE_RC ( VDBManagerRelease ( mgr ) );
+            }
+            REQUIRE_RC ( VDatabaseOpenTableRead ( db, & tbl, "SEQUENCE" ) );
+            REQUIRE_RC ( VDatabaseRelease ( db ) );
+        }
+
+        REQUIRE_NOT_NULL ( tbl );
+
+        REQUIRE_RC ( VTableListReadableColumns ( tbl, & columns ) );
+        REQUIRE_RC ( VTableRelease ( (VTable*) tbl ) );
+    }
+
+    uint32_t count = 0;
+    REQUIRE_RC ( KNamelistCount ( columns, & count ) );
+    REQUIRE_EQ ( 29u, count );
+
+    REQUIRE_RC ( KNamelistRelease ( columns ) );
+}
+
+// VTableCursor
 
 class TableCursorFixture
 {
@@ -88,8 +124,7 @@ public:
 
     void MakeReadCursorAddColumnOpen( const char * p_dbName, const char * p_colName )
     {
-        MakeReadCursor ( p_dbName );
-        THROW_ON_RC ( VCursorAddColumn ( m_cur, & m_columnIdx, "%s", p_colName ) );
+        MakeReadCursorAddColumn ( p_dbName, p_colName );
         THROW_ON_RC ( VCursorOpen ( m_cur ) );
     }
 
@@ -116,7 +151,6 @@ public:
     uint32_t  m_columnIdx;
 };
 
-const char * Accession = "SRR600096";
 const char * Column = "SPOT_GROUP";
 
 // The original purpose of these tests was to cover all VTableCursor methods in the process of
@@ -508,9 +542,17 @@ FIXTURE_TEST_CASE( VTableCursor_SetCacheCapacity, TableCursorFixture )
 FIXTURE_TEST_CASE( VTableCursor_Columns, TableCursorFixture )
 {
     MakeReadCursorAddColumnOpen ( Accession, Column );
-    VCursorCache * cols = VCursorColumns ( (VCursor*)m_cur );
+    VCursorCache * cols = VCursorColumns ( (VCursor*)m_cur, eTable );
     REQUIRE_EQ ( 6u, VectorLength ( & cols -> cache ) );
 }
+FIXTURE_TEST_CASE( VTableCursor_GetColumn, TableCursorFixture )
+{
+    MakeReadCursorAddColumnOpen ( Accession, Column );
+    VCtxId id = { 5, 3, eTable };
+    VColumn * col = VCursorGetColumn ( (VCursor*)m_cur, & id );
+    REQUIRE_NOT_NULL ( col );
+    REQUIRE_EQ ( string ( Column ), ToCppString ( col -> scol -> name -> name ) );
+}
 
 FIXTURE_TEST_CASE( VTableCursor_PhysicalColumns, TableCursorFixture )
 {
@@ -564,7 +606,7 @@ FIXTURE_TEST_CASE( VTableCursor_FindOverride, TableCursorFixture )
 {
     MakeReadCursor ( Accession );
     VCtxId id = {5, 3};
-    const KSymbol * sym = VCursorFindOverride ( m_cur, & id );
+    const KSymbol * sym = VCursorFindOverride ( m_cur, & id, VCursorGetTable ( m_cur ), NULL );
     REQUIRE_NOT_NULL ( sym );
     REQUIRE_EQ ( string ("out_spot_group"), ToCppString ( sym -> name ) );
 }
@@ -603,6 +645,37 @@ FIXTURE_TEST_CASE( VTableCursor_InstallTrigger, TableCursorFixture )
     REQUIRE_RC_FAIL ( VCursorInstallTrigger ( (VCursor*)m_cur, & prod ) ); // write side only
 }
 
+void CC incrementUint32 ( BSTNode *n, void *data )
+{
+    uint32_t * count = reinterpret_cast<uint32_t *> ( data );
+    ++ * count;
+}
+
+FIXTURE_TEST_CASE( VTableCursor_ListReadableColumns, TableCursorFixture )
+{
+    MakeReadCursor ( Accession );
+    REQUIRE_RC ( VCursorOpen ( m_cur ) );
+
+    BSTree columns; // VColumnRef
+    BSTreeInit ( & columns );
+    REQUIRE_RC ( VCursorListReadableColumns ( (VCursor *) m_cur, & columns ) );
+    REQUIRE_NOT_NULL ( columns . root );
+
+    uint32_t count = 0;
+    BSTreeForEach ( & columns, false, incrementUint32, & count );
+    REQUIRE_EQ ( 45u, count );
+
+    VColumnRef * root = ( VColumnRef * ) columns . root;
+    REQUIRE_EQ ( string ( "READ" ), ToCppString ( root -> name ) );
+    VColumnRef * child = ( VColumnRef * ) root -> n . child [ 0 ];
+    REQUIRE_EQ ( string ( "CS_NATIVE" ), ToCppString ( child -> name ) );
+    child = ( VColumnRef * ) root -> n . child [ 1 ];
+    REQUIRE_EQ ( string ( "READ_TYPE" ), ToCppString ( child -> name ) );
+    // etc.
+
+    BSTreeWhack ( &columns, VColumnRefWhack, NULL );
+}
+
 //////////////////////////////////////////// Main
 #include <kfg/config.h>
 
