@@ -29,15 +29,19 @@
 #include <klib/debug.h> /* KDbgSetString */
 #include <ktst/unit_test.hpp> // TEST_SUITE
 #include <sra/sraschema.h> // VDBManagerMakeSRASchema
+
 #include <vdb/cursor.h> /* VCursor */
+#include <vdb/database.h> /* VDatabase */
 #include <vdb/manager.h> /* VDBManager */
+#include <vdb/schema.h> /* VSchema */
 #include <vdb/table.h> /* VTable */
 #include <vdb/vdb-priv.h> /* VDBManagerMakeReadWithVFSManager */
+
 #include <vfs/manager.h> /* VFSManager */
 #include <vfs/manager-priv.h> /* VFSManagerMakeFromKfg */
 #include <vfs/resolver.h> /* VResolverCacheEnable */
-#include <vdb/database.h> /* VDatabase */
-#include <vdb/schema.h> /* VSchema */
+
+#include <os-native.h> // setenv
 
 #define ALL
 
@@ -54,7 +58,7 @@ typedef enum {
     eAppsRefseq                      =      1,
     eAppsSra                         =      2,
     eAppsWgs                         =      4,
-    
+
     eUserCacheDisabledSetFalse       =   0x20, //                 10b
     eUserCacheDisabledSetTrue        =   0x30, //                 11b
 
@@ -213,8 +217,8 @@ public:
     {
 #define WGS "AFVF01"
         const char * acc = type == eRefseq ? "KC702199.1" :
-                           type == eSra    ? "SRR003325" : WGS ".1"; 
-//                         type == eSra    ? "SRR053325" : WGS ".1"; 
+                           type == eSra    ? "SRR003325" : WGS ".1";
+//                         type == eSra    ? "SRR053325" : WGS ".1";
         rc_t rc = 0;
         KDirectory * native  = NULL;
         REQUIRE_RC ( KDirectoryNativeDir ( & native ) );
@@ -257,7 +261,7 @@ public:
         REQUIRE_RC ( VDBManagerMakeSRASchema ( mgr, & schema ) );
 
         // KConfigReadString creates NULL-terminated strings
-        REQUIRE ( user_root ); 
+        REQUIRE ( user_root );
         REQUIRE_EQ ( KDirectoryPathType ( native, user_root -> addr ),
                      ( KPathType ) kptNotFound );
         const VDatabase * db = NULL;
@@ -270,7 +274,7 @@ public:
         }
 
         // KConfigReadString creates NULL-terminated strings
-        REQUIRE ( user_root ); 
+        REQUIRE ( user_root );
         if ( caching ) {
             REQUIRE_EQ ( KDirectoryPathType ( native, user_root -> addr ),
                          ( KPathType ) kptDir );
@@ -307,7 +311,7 @@ public:
         RELEASE ( KDirectory, dir );
 
         // KConfigReadString creates NULL-terminated strings
-        REQUIRE ( user_root ); 
+        REQUIRE ( user_root );
         REQUIRE_RC ( KDirectoryRemove ( native, true, user_root -> addr ) );
         REQUIRE_EQ ( KDirectoryPathType ( native, user_root -> addr ),
                      ( KPathType ) kptNotFound );
@@ -321,7 +325,7 @@ public:
         RELEASE ( String, user_root );
 
         // KConfigReadString creates NULL-terminated strings
-        REQUIRE ( test_root ); 
+        REQUIRE ( test_root );
         KDirectoryRemove ( native, false, test_root -> addr );
         // might fail when there is another test build running parallelly
 
@@ -633,6 +637,7 @@ extern "C" {
         return 0;
     }
     rc_t CC KMain ( int argc, char * argv [] ) {
+        setenv("HOME", ".", 1);
         KConfigDisableUserSettings ();
 if (
 0 ) assert ( ! KDbgSetString ( "VFS" ) );
