@@ -383,8 +383,9 @@ TEST_SUITE ( TestResolver4 )
 extern "C" {
     ver_t CC KAppVersion ( void ) { return 0; }
     rc_t CC KMain ( int argc, char * argv [] ) {
-if ( 
-0 ) assert ( ! KDbgSetString ( "VFS-JSON" ) );
+        if ( 
+0 )
+            assert ( ! KDbgSetString ( "VFS-JSON" ) );
     return TestResolver4 ( argc, argv );
     }
 }
