@@ -61,19 +61,19 @@ class P {
 
 static int getDigit ( char c, rc_t * rc ) {
         assert ( rc );
- 
+
         if ( * rc != 0 )
             return 0;
- 
-        c = tolower ( c );
+
+        c = (char) tolower ( c );
         if ( ! isdigit ( c ) && c < 'a' && c > 'f' ) {
             * rc = RC ( rcVFS, rcQuery, rcExecuting, rcItem, rcIncorrect );
             return 0;
         }
- 
+
         if ( isdigit ( c ) )
             return c - '0';
- 
+
         return c - 'a' + 10;
     }
 
@@ -97,7 +97,7 @@ public:
             if ( tt != NULL )
                 t = KTimeMakeTime ( & kt );
         }
-	
+
         uint8_t ud5 [ 16 ];
         uint8_t * pd5 = NULL;
         if ( md5 . size () == 32 ) {
@@ -515,7 +515,7 @@ extern "C" {
     rc_t CC Usage        ( const struct Args * args ) { return 0; }
     ver_t CC KAppVersion ( void ) { return 0; }
     rc_t CC KMain ( int argc, char * argv [] ) {
-        if ( 
+        if (
 0 ) assert ( ! KDbgSetString ( "VFS" ) );
 
         KConfigDisableUserSettings ();
